# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class InstallNodeUpdateRequest(Model):
    """InstallNodeUpdateRequest.

    All required parameters must be populated in order to send to Azure.

    :param status_id: Required. The Installation status identifier of the
     nodes at time of install.
    :type status_id: int
    :param status_note: Installations notes typically used when a node is
     unable to be installed.
    :type status_note: str
    """

    _validation = {
        'status_id': {'required': True},
        'status_note': {'max_length': 200, 'min_length': 0},
    }

    _attribute_map = {
        'status_id': {'key': 'StatusId', 'type': 'int'},
        'status_note': {'key': 'StatusNote', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(InstallNodeUpdateRequest, self).__init__(**kwargs)
        self.status_id = kwargs.get('status_id', None)
        self.status_note = kwargs.get('status_note', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from .smart_diagnostics_api import SmartDiagnosticsApi
from .version import VERSION

__all__ = ['SmartDiagnosticsApi']

__version__ = VERSION




# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AssetSizeChild(Model):
    """AssetSizeChild.

    All required parameters must be populated in order to send to Azure.

    :param size_id: Required.
    :type size_id: int
    :param size_name: Required.
    :type size_name: str
    :param size_code: Required.
    :type size_code: str
    """

    _validation = {
        'size_id': {'required': True},
        'size_name': {'required': True},
        'size_code': {'required': True},
    }

    _attribute_map = {
        'size_id': {'key': 'SizeId', 'type': 'int'},
        'size_name': {'key': 'SizeName', 'type': 'str'},
        'size_code': {'key': 'SizeCode', 'type': 'str'},
    }

    def __init__(self, *, size_id: int, size_name: str, size_code: str, **kwargs) -> None:
        super(AssetSizeChild, self).__init__(**kwargs)
        self.size_id = size_id
        self.size_name = size_name
        self.size_code = size_code



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PersonalAccessTokenCreateResponse(Model):
    """PersonalAccessTokenCreateResponse.

    :param id:
    :type id: str
    :param description:
    :type description: str
    :param token:
    :type token: str
    :param note:
    :type note: str
    """

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'str'},
        'description': {'key': 'Description', 'type': 'str'},
        'token': {'key': 'Token', 'type': 'str'},
        'note': {'key': 'Note', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(PersonalAccessTokenCreateResponse, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.description = kwargs.get('description', None)
        self.token = kwargs.get('token', None)
        self.note = kwargs.get('note', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class LocationCreateRequest(Model):
    """LocationCreateRequest.

    All required parameters must be populated in order to send to Azure.

    :param name: Required.
    :type name: str
    :param abbreviation:
    :type abbreviation: str
    :param corporation_id: Required.
    :type corporation_id: str
    """

    _validation = {
        'name': {'required': True, 'max_length': 50},
        'abbreviation': {'max_length': 5},
        'corporation_id': {'required': True},
    }

    _attribute_map = {
        'name': {'key': 'Name', 'type': 'str'},
        'abbreviation': {'key': 'Abbreviation', 'type': 'str'},
        'corporation_id': {'key': 'CorporationId', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(LocationCreateRequest, self).__init__(**kwargs)
        self.name = kwargs.get('name', None)
        self.abbreviation = kwargs.get('abbreviation', None)
        self.corporation_id = kwargs.get('corporation_id', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SystemCreateRequest(Model):
    """SystemCreateRequest.

    All required parameters must be populated in order to send to Azure.

    :param name: Required.
    :type name: str
    :param abbreviation:
    :type abbreviation: str
    :param location_id: Required.
    :type location_id: str
    :param is_collector_dependent_system: Required.
    :type is_collector_dependent_system: bool
    :param description:
    :type description: str
    :param is_visible: Required.
    :type is_visible: bool
    :param cds_master_system_ids:
    :type cds_master_system_ids: list[str]
    :param cds_base_station_ids:
    :type cds_base_station_ids: list[long]
    """

    _validation = {
        'name': {'required': True, 'max_length': 100},
        'abbreviation': {'max_length': 5},
        'location_id': {'required': True},
        'is_collector_dependent_system': {'required': True},
        'description': {'max_length': 1000},
        'is_visible': {'required': True},
    }

    _attribute_map = {
        'name': {'key': 'Name', 'type': 'str'},
        'abbreviation': {'key': 'Abbreviation', 'type': 'str'},
        'location_id': {'key': 'LocationId', 'type': 'str'},
        'is_collector_dependent_system': {'key': 'IsCollectorDependentSystem', 'type': 'bool'},
        'description': {'key': 'Description', 'type': 'str'},
        'is_visible': {'key': 'IsVisible', 'type': 'bool'},
        'cds_master_system_ids': {'key': 'CdsMasterSystemIds', 'type': '[str]'},
        'cds_base_station_ids': {'key': 'CdsBaseStationIds', 'type': '[long]'},
    }

    def __init__(self, **kwargs):
        super(SystemCreateRequest, self).__init__(**kwargs)
        self.name = kwargs.get('name', None)
        self.abbreviation = kwargs.get('abbreviation', None)
        self.location_id = kwargs.get('location_id', None)
        self.is_collector_dependent_system = kwargs.get('is_collector_dependent_system', None)
        self.description = kwargs.get('description', None)
        self.is_visible = kwargs.get('is_visible', None)
        self.cds_master_system_ids = kwargs.get('cds_master_system_ids', None)
        self.cds_base_station_ids = kwargs.get('cds_base_station_ids', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DashboardResponse(Model):
    """DashboardResponse.

    All required parameters must be populated in order to send to Azure.

    :param id: Required.
    :type id: str
    :param name: Required.
    :type name: str
    :param description:
    :type description: str
    :param is_sentry_managed: Required.
    :type is_sentry_managed: bool
    :param is_visible_to_customers: Required.
    :type is_visible_to_customers: bool
    :param created: Required.
    :type created: datetime
    :param updated: Required.
    :type updated: datetime
    :param created_by:
    :type created_by: ~smartdiagnostics_sdk.models.UserChild
    :param updated_by:
    :type updated_by: ~smartdiagnostics_sdk.models.UserChild
    :param dashboard_type:
    :type dashboard_type: ~smartdiagnostics_sdk.models.DashboardTypeChild
    :param corporation:
    :type corporation: ~smartdiagnostics_sdk.models.PrimaryCorporationChild
    :param location:
    :type location: ~smartdiagnostics_sdk.models.LocationChild
    :param dashboard_widgets:
    :type dashboard_widgets:
     list[~smartdiagnostics_sdk.models.DashboardWidgetChild]
    :param power_bi_report:
    :type power_bi_report: ~smartdiagnostics_sdk.models.PowerBiReportChild
    """

    _validation = {
        'id': {'required': True},
        'name': {'required': True},
        'is_sentry_managed': {'required': True},
        'is_visible_to_customers': {'required': True},
        'created': {'required': True},
        'updated': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'str'},
        'name': {'key': 'Name', 'type': 'str'},
        'description': {'key': 'Description', 'type': 'str'},
        'is_sentry_managed': {'key': 'IsSentryManaged', 'type': 'bool'},
        'is_visible_to_customers': {'key': 'IsVisibleToCustomers', 'type': 'bool'},
        'created': {'key': 'Created', 'type': 'iso-8601'},
        'updated': {'key': 'Updated', 'type': 'iso-8601'},
        'created_by': {'key': 'CreatedBy', 'type': 'UserChild'},
        'updated_by': {'key': 'UpdatedBy', 'type': 'UserChild'},
        'dashboard_type': {'key': 'DashboardType', 'type': 'DashboardTypeChild'},
        'corporation': {'key': 'Corporation', 'type': 'PrimaryCorporationChild'},
        'location': {'key': 'Location', 'type': 'LocationChild'},
        'dashboard_widgets': {'key': 'DashboardWidgets', 'type': '[DashboardWidgetChild]'},
        'power_bi_report': {'key': 'PowerBiReport', 'type': 'PowerBiReportChild'},
    }

    def __init__(self, **kwargs):
        super(DashboardResponse, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.name = kwargs.get('name', None)
        self.description = kwargs.get('description', None)
        self.is_sentry_managed = kwargs.get('is_sentry_managed', None)
        self.is_visible_to_customers = kwargs.get('is_visible_to_customers', None)
        self.created = kwargs.get('created', None)
        self.updated = kwargs.get('updated', None)
        self.created_by = kwargs.get('created_by', None)
        self.updated_by = kwargs.get('updated_by', None)
        self.dashboard_type = kwargs.get('dashboard_type', None)
        self.corporation = kwargs.get('corporation', None)
        self.location = kwargs.get('location', None)
        self.dashboard_widgets = kwargs.get('dashboard_widgets', None)
        self.power_bi_report = kwargs.get('power_bi_report', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BaseStationChild(Model):
    """BaseStationChild.

    All required parameters must be populated in order to send to Azure.

    :param base_station_id: Required.
    :type base_station_id: long
    :param base_station_nickname:
    :type base_station_nickname: str
    :param base_station_serial_number:
    :type base_station_serial_number: str
    """

    _validation = {
        'base_station_id': {'required': True},
    }

    _attribute_map = {
        'base_station_id': {'key': 'BaseStationId', 'type': 'long'},
        'base_station_nickname': {'key': 'BaseStationNickname', 'type': 'str'},
        'base_station_serial_number': {'key': 'BaseStationSerialNumber', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(BaseStationChild, self).__init__(**kwargs)
        self.base_station_id = kwargs.get('base_station_id', None)
        self.base_station_nickname = kwargs.get('base_station_nickname', None)
        self.base_station_serial_number = kwargs.get('base_station_serial_number', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class NodeSettingValues(Model):
    """NodeSettingValues.

    :param current_value:
    :type current_value: str
    :param pending_value:
    :type pending_value: str
    """

    _attribute_map = {
        'current_value': {'key': 'CurrentValue', 'type': 'str'},
        'pending_value': {'key': 'PendingValue', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(NodeSettingValues, self).__init__(**kwargs)
        self.current_value = kwargs.get('current_value', None)
        self.pending_value = kwargs.get('pending_value', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GroupAnalyticsModelAddRequest(Model):
    """GroupAnalyticsModelAddRequest.

    All required parameters must be populated in order to send to Azure.

    :param model_id: Required.
    :type model_id: int
    :param properties:
    :type properties: list[~smartdiagnostics_sdk.models.SetPropertyChild]
    """

    _validation = {
        'model_id': {'required': True},
    }

    _attribute_map = {
        'model_id': {'key': 'ModelId', 'type': 'int'},
        'properties': {'key': 'Properties', 'type': '[SetPropertyChild]'},
    }

    def __init__(self, **kwargs):
        super(GroupAnalyticsModelAddRequest, self).__init__(**kwargs)
        self.model_id = kwargs.get('model_id', None)
        self.properties = kwargs.get('properties', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class NodeResponse(Model):
    """NodeResponse.

    All required parameters must be populated in order to send to Azure.

    :param id: Required.
    :type id: long
    :param location: Required.
    :type location: ~smartdiagnostics_sdk.models.LocationChild
    :param corporation: Required.
    :type corporation: ~smartdiagnostics_sdk.models.CorporationChild
    :param hub:
    :type hub: ~smartdiagnostics_sdk.models.HubChild
    :param base_station: Required.
    :type base_station: ~smartdiagnostics_sdk.models.BaseStationNodeChild
    :param repeater:
    :type repeater: ~smartdiagnostics_sdk.models.RepeaterNodeChild
    :param serial_number: Required.
    :type serial_number: str
    :param nickname:
    :type nickname: str
    :param firmware_version:
    :type firmware_version: str
    :param node_type_code: Required. Possible values include: 'Invalid',
     'KcfFlow', 'KcfPressureVoltage', 'KcfPressureCurrent', 'KcfPower',
     'KcfVibration', 'KcfVibrationV1', 'KcfVoltage', 'KcfCurrent',
     'KcfAtoDVoltage', 'KcfAtoDCurrent', 'KcfOilQuality', 'Generic',
     'KcfAgnostic', 'KcfHumidity', 'KcfExtendedTemperatureVibration',
     'KcfHubVibrationV1', 'KcfHubAnalogAdapterV1'
    :type node_type_code: str or ~smartdiagnostics_sdk.models.enum
    :param active: Required.
    :type active: bool
    :param created: Required.
    :type created: datetime
    :param updated: Required.
    :type updated: datetime
    :param battery_voltage:
    :type battery_voltage: float
    :param burst_success_rate:
    :type burst_success_rate: float
    :param is_online:
    :type is_online: bool
    :param last_update_time:
    :type last_update_time: datetime
    :param packet_success_rate:
    :type packet_success_rate: float
    :param temperature:
    :type temperature: float
    :param wireless_efficiency:
    :type wireless_efficiency: float
    """

    _validation = {
        'id': {'required': True},
        'location': {'required': True},
        'corporation': {'required': True},
        'base_station': {'required': True},
        'serial_number': {'required': True, 'max_length': 8},
        'nickname': {'max_length': 30},
        'node_type_code': {'required': True},
        'active': {'required': True},
        'created': {'required': True},
        'updated': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'long'},
        'location': {'key': 'Location', 'type': 'LocationChild'},
        'corporation': {'key': 'Corporation', 'type': 'CorporationChild'},
        'hub': {'key': 'Hub', 'type': 'HubChild'},
        'base_station': {'key': 'BaseStation', 'type': 'BaseStationNodeChild'},
        'repeater': {'key': 'Repeater', 'type': 'RepeaterNodeChild'},
        'serial_number': {'key': 'SerialNumber', 'type': 'str'},
        'nickname': {'key': 'Nickname', 'type': 'str'},
        'firmware_version': {'key': 'FirmwareVersion', 'type': 'str'},
        'node_type_code': {'key': 'NodeTypeCode', 'type': 'str'},
        'active': {'key': 'Active', 'type': 'bool'},
        'created': {'key': 'Created', 'type': 'iso-8601'},
        'updated': {'key': 'Updated', 'type': 'iso-8601'},
        'battery_voltage': {'key': 'BatteryVoltage', 'type': 'float'},
        'burst_success_rate': {'key': 'BurstSuccessRate', 'type': 'float'},
        'is_online': {'key': 'IsOnline', 'type': 'bool'},
        'last_update_time': {'key': 'LastUpdateTime', 'type': 'iso-8601'},
        'packet_success_rate': {'key': 'PacketSuccessRate', 'type': 'float'},
        'temperature': {'key': 'Temperature', 'type': 'float'},
        'wireless_efficiency': {'key': 'WirelessEfficiency', 'type': 'float'},
    }

    def __init__(self, *, id: int, location, corporation, base_station, serial_number: str, node_type_code, active: bool, created, updated, hub=None, repeater=None, nickname: str=None, firmware_version: str=None, battery_voltage: float=None, burst_success_rate: float=None, is_online: bool=None, last_update_time=None, packet_success_rate: float=None, temperature: float=None, wireless_efficiency: float=None, **kwargs) -> None:
        super(NodeResponse, self).__init__(**kwargs)
        self.id = id
        self.location = location
        self.corporation = corporation
        self.hub = hub
        self.base_station = base_station
        self.repeater = repeater
        self.serial_number = serial_number
        self.nickname = nickname
        self.firmware_version = firmware_version
        self.node_type_code = node_type_code
        self.active = active
        self.created = created
        self.updated = updated
        self.battery_voltage = battery_voltage
        self.burst_success_rate = burst_success_rate
        self.is_online = is_online
        self.last_update_time = last_update_time
        self.packet_success_rate = packet_success_rate
        self.temperature = temperature
        self.wireless_efficiency = wireless_efficiency



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CurrentUserResponse(Model):
    """CurrentUserResponse.

    :param id:
    :type id: str
    :param email:
    :type email: str
    :param first_name:
    :type first_name: str
    :param last_name:
    :type last_name: str
    :param phone_number:
    :type phone_number: str
    :param application_role: Possible values include: 'Invalid', 'SaasAdmin',
     'AccountAdmin', 'ApplicationUser', 'Technician', 'User', 'SystemProcess',
     'Sentry', 'Sales', 'CorporationAdmin', 'CorporationUser',
     'CorporationNone'
    :type application_role: str or ~smartdiagnostics_sdk.models.enum
    :param corporations:
    :type corporations:
     list[~smartdiagnostics_sdk.models.UserCorporationChild]
    :param locations:
    :type locations: list[~smartdiagnostics_sdk.models.UserLocationChild]
    :param profile:
    :type profile: ~smartdiagnostics_sdk.models.ProfileChild
    """

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'str'},
        'email': {'key': 'Email', 'type': 'str'},
        'first_name': {'key': 'FirstName', 'type': 'str'},
        'last_name': {'key': 'LastName', 'type': 'str'},
        'phone_number': {'key': 'PhoneNumber', 'type': 'str'},
        'application_role': {'key': 'ApplicationRole', 'type': 'str'},
        'corporations': {'key': 'Corporations', 'type': '[UserCorporationChild]'},
        'locations': {'key': 'Locations', 'type': '[UserLocationChild]'},
        'profile': {'key': 'Profile', 'type': 'ProfileChild'},
    }

    def __init__(self, **kwargs):
        super(CurrentUserResponse, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.email = kwargs.get('email', None)
        self.first_name = kwargs.get('first_name', None)
        self.last_name = kwargs.get('last_name', None)
        self.phone_number = kwargs.get('phone_number', None)
        self.application_role = kwargs.get('application_role', None)
        self.corporations = kwargs.get('corporations', None)
        self.locations = kwargs.get('locations', None)
        self.profile = kwargs.get('profile', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AssetRunningSpeedChild(Model):
    """AssetRunningSpeedChild.

    :param running_speed_min:
    :type running_speed_min: float
    :param running_speed_max:
    :type running_speed_max: float
    :param running_speed_type:
    :type running_speed_type: str
    :param running_speed_reference_monitoring_point_id:
    :type running_speed_reference_monitoring_point_id: str
    :param running_speed_sensor_role_type: Possible values include: 'Invalid',
     'CurrentPhaseA', 'PeakCurrentPhaseA', 'CurrentPhaseB',
     'PeakCurrentPhaseB', 'CurrentPhaseC', 'PeakCurrentPhaseC',
     'DifferentialPressure', 'Flow', 'Humidity', 'NodeTemperature',
     'NodeVoltage', 'PeakVibration', 'Pressure', 'RmsVibration',
     'SignalStrength', 'StandardAirVelocity', 'SupplyVoltage', 'Temperature',
     'TotalCurrent', 'VibrationXAxis', 'VibrationYAxis', 'Voltage', 'Current',
     'AtoDChannel1', 'AtoDChannel2', 'AtoDChannel3', 'AtoDChannel4',
     'AtoDChannel5', 'AtoDChannel6', 'OilTemperature', 'OilHumidity', 'X', 'Y',
     'Z', 'Custom', 'WirelessEfficiency', 'PacketSuccessRate', 'NodeHumidity',
     'BurstSuccessRate'
    :type running_speed_sensor_role_type: str or
     ~smartdiagnostics_sdk.models.enum
    :param running_speed_harmonic:
    :type running_speed_harmonic: float
    """

    _attribute_map = {
        'running_speed_min': {'key': 'RunningSpeedMin', 'type': 'float'},
        'running_speed_max': {'key': 'RunningSpeedMax', 'type': 'float'},
        'running_speed_type': {'key': 'RunningSpeedType', 'type': 'str'},
        'running_speed_reference_monitoring_point_id': {'key': 'RunningSpeedReferenceMonitoringPointId', 'type': 'str'},
        'running_speed_sensor_role_type': {'key': 'RunningSpeedSensorRoleType', 'type': 'str'},
        'running_speed_harmonic': {'key': 'RunningSpeedHarmonic', 'type': 'float'},
    }

    def __init__(self, *, running_speed_min: float=None, running_speed_max: float=None, running_speed_type: str=None, running_speed_reference_monitoring_point_id: str=None, running_speed_sensor_role_type=None, running_speed_harmonic: float=None, **kwargs) -> None:
        super(AssetRunningSpeedChild, self).__init__(**kwargs)
        self.running_speed_min = running_speed_min
        self.running_speed_max = running_speed_max
        self.running_speed_type = running_speed_type
        self.running_speed_reference_monitoring_point_id = running_speed_reference_monitoring_point_id
        self.running_speed_sensor_role_type = running_speed_sensor_role_type
        self.running_speed_harmonic = running_speed_harmonic



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DashboardWidgetRequestChild(Model):
    """DashboardWidgetRequestChild.

    All required parameters must be populated in order to send to Azure.

    :param dashboard_widget_id: Required.
    :type dashboard_widget_id: str
    :param dashboard_widget_row: Required.
    :type dashboard_widget_row: int
    :param dashboard_widget_column: Required.
    :type dashboard_widget_column: int
    :param dashboard_widget_height: Required.
    :type dashboard_widget_height: int
    :param dashboard_widget_width: Required.
    :type dashboard_widget_width: int
    """

    _validation = {
        'dashboard_widget_id': {'required': True},
        'dashboard_widget_row': {'required': True},
        'dashboard_widget_column': {'required': True},
        'dashboard_widget_height': {'required': True},
        'dashboard_widget_width': {'required': True},
    }

    _attribute_map = {
        'dashboard_widget_id': {'key': 'DashboardWidgetId', 'type': 'str'},
        'dashboard_widget_row': {'key': 'DashboardWidgetRow', 'type': 'int'},
        'dashboard_widget_column': {'key': 'DashboardWidgetColumn', 'type': 'int'},
        'dashboard_widget_height': {'key': 'DashboardWidgetHeight', 'type': 'int'},
        'dashboard_widget_width': {'key': 'DashboardWidgetWidth', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(DashboardWidgetRequestChild, self).__init__(**kwargs)
        self.dashboard_widget_id = kwargs.get('dashboard_widget_id', None)
        self.dashboard_widget_row = kwargs.get('dashboard_widget_row', None)
        self.dashboard_widget_column = kwargs.get('dashboard_widget_column', None)
        self.dashboard_widget_height = kwargs.get('dashboard_widget_height', None)
        self.dashboard_widget_width = kwargs.get('dashboard_widget_width', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WidgetTemplateChild(Model):
    """WidgetTemplateChild.

    All required parameters must be populated in order to send to Azure.

    :param widget_template_name: Required.
    :type widget_template_name: str
    :param widget_template_description:
    :type widget_template_description: str
    :param widget_template_filters:
    :type widget_template_filters:
     list[~smartdiagnostics_sdk.models.WidgetTemplateFilterChild]
    """

    _validation = {
        'widget_template_name': {'required': True},
    }

    _attribute_map = {
        'widget_template_name': {'key': 'WidgetTemplateName', 'type': 'str'},
        'widget_template_description': {'key': 'WidgetTemplateDescription', 'type': 'str'},
        'widget_template_filters': {'key': 'WidgetTemplateFilters', 'type': '[WidgetTemplateFilterChild]'},
    }

    def __init__(self, **kwargs):
        super(WidgetTemplateChild, self).__init__(**kwargs)
        self.widget_template_name = kwargs.get('widget_template_name', None)
        self.widget_template_description = kwargs.get('widget_template_description', None)
        self.widget_template_filters = kwargs.get('widget_template_filters', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AnalyticsModelUpdateRequest(Model):
    """AnalyticsModelUpdateRequest.

    All required parameters must be populated in order to send to Azure.

    :param is_deprecated: Required.
    :type is_deprecated: bool
    :param name: Required.
    :type name: str
    :param version: Required.
    :type version: str
    :param group_type: Possible values include: 'Asset', 'MonitoringPoint',
     'IndicatorGroup', 'Group', 'AnalyticModel'
    :type group_type: str or ~smartdiagnostics_sdk.models.enum
    :param indicators:
    :type indicators:
     list[~smartdiagnostics_sdk.models.AnalyticsModelIndicatorChild]
    :param related_model_ids:
    :type related_model_ids: list[int]
    :param properties:
    :type properties: list[~smartdiagnostics_sdk.models.PropertyRequestChild]
    :param triggers:
    :type triggers: list[~smartdiagnostics_sdk.models.TriggerChild]
    """

    _validation = {
        'is_deprecated': {'required': True},
        'name': {'required': True, 'max_length': 50, 'min_length': 0},
        'version': {'required': True, 'max_length': 50, 'min_length': 0},
    }

    _attribute_map = {
        'is_deprecated': {'key': 'IsDeprecated', 'type': 'bool'},
        'name': {'key': 'Name', 'type': 'str'},
        'version': {'key': 'Version', 'type': 'str'},
        'group_type': {'key': 'GroupType', 'type': 'str'},
        'indicators': {'key': 'Indicators', 'type': '[AnalyticsModelIndicatorChild]'},
        'related_model_ids': {'key': 'RelatedModelIds', 'type': '[int]'},
        'properties': {'key': 'Properties', 'type': '[PropertyRequestChild]'},
        'triggers': {'key': 'Triggers', 'type': '[TriggerChild]'},
    }

    def __init__(self, *, is_deprecated: bool, name: str, version: str, group_type=None, indicators=None, related_model_ids=None, properties=None, triggers=None, **kwargs) -> None:
        super(AnalyticsModelUpdateRequest, self).__init__(**kwargs)
        self.is_deprecated = is_deprecated
        self.name = name
        self.version = version
        self.group_type = group_type
        self.indicators = indicators
        self.related_model_ids = related_model_ids
        self.properties = properties
        self.triggers = triggers



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DashboardTemplateResponse(Model):
    """DashboardTemplateResponse.

    All required parameters must be populated in order to send to Azure.

    :param id: Required.
    :type id: int
    :param name: Required.
    :type name: str
    :param description:
    :type description: str
    :param dashboard_type_id:
    :type dashboard_type_id: int
    :param widget_templates:
    :type widget_templates:
     list[~smartdiagnostics_sdk.models.WidgetTemplateChild]
    """

    _validation = {
        'id': {'required': True},
        'name': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'int'},
        'name': {'key': 'Name', 'type': 'str'},
        'description': {'key': 'Description', 'type': 'str'},
        'dashboard_type_id': {'key': 'DashboardTypeId', 'type': 'int'},
        'widget_templates': {'key': 'WidgetTemplates', 'type': '[WidgetTemplateChild]'},
    }

    def __init__(self, **kwargs):
        super(DashboardTemplateResponse, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.name = kwargs.get('name', None)
        self.description = kwargs.get('description', None)
        self.dashboard_type_id = kwargs.get('dashboard_type_id', None)
        self.widget_templates = kwargs.get('widget_templates', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CorporationResponse(Model):
    """CorporationResponse.

    All required parameters must be populated in order to send to Azure.

    :param id: Required.
    :type id: str
    :param name: Required.
    :type name: str
    :param abbreviation:
    :type abbreviation: str
    :param icon_url:
    :type icon_url: str
    :param active:
    :type active: bool
    :param created:
    :type created: datetime
    :param industry:
    :type industry: ~smartdiagnostics_sdk.models.CorporationIndustryChild
    :param locations:
    :type locations: list[~smartdiagnostics_sdk.models.LocationChild]
    """

    _validation = {
        'id': {'required': True},
        'name': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'str'},
        'name': {'key': 'Name', 'type': 'str'},
        'abbreviation': {'key': 'Abbreviation', 'type': 'str'},
        'icon_url': {'key': 'IconUrl', 'type': 'str'},
        'active': {'key': 'Active', 'type': 'bool'},
        'created': {'key': 'Created', 'type': 'iso-8601'},
        'industry': {'key': 'Industry', 'type': 'CorporationIndustryChild'},
        'locations': {'key': 'Locations', 'type': '[LocationChild]'},
    }

    def __init__(self, **kwargs):
        super(CorporationResponse, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.name = kwargs.get('name', None)
        self.abbreviation = kwargs.get('abbreviation', None)
        self.icon_url = kwargs.get('icon_url', None)
        self.active = kwargs.get('active', None)
        self.created = kwargs.get('created', None)
        self.industry = kwargs.get('industry', None)
        self.locations = kwargs.get('locations', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class HubNodeChild(Model):
    """HubNodeChild.

    :param node_id:
    :type node_id: long
    :param node_serial_number:
    :type node_serial_number: str
    :param node_nickname:
    :type node_nickname: str
    :param is_online:
    :type is_online: bool
    :param node_settings:
    :type node_settings: list[~smartdiagnostics_sdk.models.NodeSettingChild]
    :param latest_long_burst:
    :type latest_long_burst:
     ~smartdiagnostics_sdk.models.LongBurstRequestChild
    """

    _attribute_map = {
        'node_id': {'key': 'NodeId', 'type': 'long'},
        'node_serial_number': {'key': 'NodeSerialNumber', 'type': 'str'},
        'node_nickname': {'key': 'NodeNickname', 'type': 'str'},
        'is_online': {'key': 'IsOnline', 'type': 'bool'},
        'node_settings': {'key': 'NodeSettings', 'type': '[NodeSettingChild]'},
        'latest_long_burst': {'key': 'LatestLongBurst', 'type': 'LongBurstRequestChild'},
    }

    def __init__(self, **kwargs):
        super(HubNodeChild, self).__init__(**kwargs)
        self.node_id = kwargs.get('node_id', None)
        self.node_serial_number = kwargs.get('node_serial_number', None)
        self.node_nickname = kwargs.get('node_nickname', None)
        self.is_online = kwargs.get('is_online', None)
        self.node_settings = kwargs.get('node_settings', None)
        self.latest_long_burst = kwargs.get('latest_long_burst', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FileResponse(Model):
    """FileResponse.

    All required parameters must be populated in order to send to Azure.

    :param type: Required. Possible values include: 'Invalid', 'Picture',
     'Folder'
    :type type: str or ~smartdiagnostics_sdk.models.enum
    :param display_name:
    :type display_name: str
    :param parent_folder_id: Required.
    :type parent_folder_id: str
    :param description:
    :type description: str
    :param location:
    :type location: ~smartdiagnostics_sdk.models.LocationChild
    :param corporation:
    :type corporation: ~smartdiagnostics_sdk.models.CorporationChild
    :param group_ids: Ids of groups the file belongs to
    :type group_ids: list[str]
    :param id:
    :type id: str
    :param file_name:
    :type file_name: str
    :param thumbnail_file_name:
    :type thumbnail_file_name: str
    :param creation_date:
    :type creation_date: datetime
    :param update_date:
    :type update_date: datetime
    :param file_count:
    :type file_count: int
    :param folder_count:
    :type folder_count: int
    :param is_root_folder:
    :type is_root_folder: bool
    :param tags:
    :type tags: list[~smartdiagnostics_sdk.models.TagChild]
    """

    _validation = {
        'type': {'required': True},
        'display_name': {'max_length': 223},
        'parent_folder_id': {'required': True},
    }

    _attribute_map = {
        'type': {'key': 'Type', 'type': 'str'},
        'display_name': {'key': 'DisplayName', 'type': 'str'},
        'parent_folder_id': {'key': 'ParentFolderId', 'type': 'str'},
        'description': {'key': 'Description', 'type': 'str'},
        'location': {'key': 'Location', 'type': 'LocationChild'},
        'corporation': {'key': 'Corporation', 'type': 'CorporationChild'},
        'group_ids': {'key': 'GroupIds', 'type': '[str]'},
        'id': {'key': 'Id', 'type': 'str'},
        'file_name': {'key': 'FileName', 'type': 'str'},
        'thumbnail_file_name': {'key': 'ThumbnailFileName', 'type': 'str'},
        'creation_date': {'key': 'CreationDate', 'type': 'iso-8601'},
        'update_date': {'key': 'UpdateDate', 'type': 'iso-8601'},
        'file_count': {'key': 'FileCount', 'type': 'int'},
        'folder_count': {'key': 'FolderCount', 'type': 'int'},
        'is_root_folder': {'key': 'IsRootFolder', 'type': 'bool'},
        'tags': {'key': 'Tags', 'type': '[TagChild]'},
    }

    def __init__(self, *, type, parent_folder_id: str, display_name: str=None, description: str=None, location=None, corporation=None, group_ids=None, id: str=None, file_name: str=None, thumbnail_file_name: str=None, creation_date=None, update_date=None, file_count: int=None, folder_count: int=None, is_root_folder: bool=None, tags=None, **kwargs) -> None:
        super(FileResponse, self).__init__(**kwargs)
        self.type = type
        self.display_name = display_name
        self.parent_folder_id = parent_folder_id
        self.description = description
        self.location = location
        self.corporation = corporation
        self.group_ids = group_ids
        self.id = id
        self.file_name = file_name
        self.thumbnail_file_name = thumbnail_file_name
        self.creation_date = creation_date
        self.update_date = update_date
        self.file_count = file_count
        self.folder_count = folder_count
        self.is_root_folder = is_root_folder
        self.tags = tags



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AssetsStatusCountChild(Model):
    """AssetsStatusCountChild.

    :param normal:
    :type normal: int
    :param warning:
    :type warning: int
    :param alarm:
    :type alarm: int
    """

    _attribute_map = {
        'normal': {'key': 'Normal', 'type': 'int'},
        'warning': {'key': 'Warning', 'type': 'int'},
        'alarm': {'key': 'Alarm', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(AssetsStatusCountChild, self).__init__(**kwargs)
        self.normal = kwargs.get('normal', None)
        self.warning = kwargs.get('warning', None)
        self.alarm = kwargs.get('alarm', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EventModelV3(Model):
    """EventModelV3.

    All required parameters must be populated in order to send to Azure.

    :param id:
    :type id: str
    :param location_id:
    :type location_id: str
    :param window_id:
    :type window_id: str
    :param date_occurred: Required.
    :type date_occurred: datetime
    :param description:
    :type description: str
    :param reason:
    :type reason: str
    :param content_type: Required. Possible values include: 'Invalid',
     'OperationalCondition', 'Fault', 'RootCause', 'Evidence', 'Inspection',
     'PreventativeMaintenance', 'CorrectiveMaintenance', 'Observation',
     'Document', 'Description', 'SamplingFrequencyChange',
     'PendingSamplingFrequencyChange', 'AutoInvalidBurstData',
     'UserInvalidBurstData'
    :type content_type: str or ~smartdiagnostics_sdk.models.enum
    :param attachment: Required.
    :type attachment: ~smartdiagnostics_sdk.models.AttachmentModelV3
    :param code_ids:
    :type code_ids: list[str]
    :param tag_details:
    :type tag_details: list[str]
    :param document_url:
    :type document_url: str
    :param document_name:
    :type document_name: str
    :param title:
    :type title: str
    :param evidence_indicator_id:
    :type evidence_indicator_id: str
    :param created:
    :type created: datetime
    :param created_by:
    :type created_by: str
    :param modified:
    :type modified: datetime
    :param modified_by:
    :type modified_by: str
    :param savings:
    :type savings: float
    :param group_name:
    :type group_name: str
    :param group_path:
    :type group_path: str
    :param group_type: Possible values include: 'Invalid', 'Group', 'Asset',
     'MonitoringPoint', 'IndicatorGroup', 'AnalyticModel'
    :type group_type: str or ~smartdiagnostics_sdk.models.enum
    """

    _validation = {
        'date_occurred': {'required': True},
        'content_type': {'required': True},
        'attachment': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'str'},
        'location_id': {'key': 'LocationId', 'type': 'str'},
        'window_id': {'key': 'WindowId', 'type': 'str'},
        'date_occurred': {'key': 'DateOccurred', 'type': 'iso-8601'},
        'description': {'key': 'Description', 'type': 'str'},
        'reason': {'key': 'Reason', 'type': 'str'},
        'content_type': {'key': 'ContentType', 'type': 'str'},
        'attachment': {'key': 'Attachment', 'type': 'AttachmentModelV3'},
        'code_ids': {'key': 'CodeIds', 'type': '[str]'},
        'tag_details': {'key': 'TagDetails', 'type': '[str]'},
        'document_url': {'key': 'DocumentUrl', 'type': 'str'},
        'document_name': {'key': 'DocumentName', 'type': 'str'},
        'title': {'key': 'Title', 'type': 'str'},
        'evidence_indicator_id': {'key': 'EvidenceIndicatorId', 'type': 'str'},
        'created': {'key': 'Created', 'type': 'iso-8601'},
        'created_by': {'key': 'CreatedBy', 'type': 'str'},
        'modified': {'key': 'Modified', 'type': 'iso-8601'},
        'modified_by': {'key': 'ModifiedBy', 'type': 'str'},
        'savings': {'key': 'Savings', 'type': 'float'},
        'group_name': {'key': 'GroupName', 'type': 'str'},
        'group_path': {'key': 'GroupPath', 'type': 'str'},
        'group_type': {'key': 'GroupType', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(EventModelV3, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.location_id = kwargs.get('location_id', None)
        self.window_id = kwargs.get('window_id', None)
        self.date_occurred = kwargs.get('date_occurred', None)
        self.description = kwargs.get('description', None)
        self.reason = kwargs.get('reason', None)
        self.content_type = kwargs.get('content_type', None)
        self.attachment = kwargs.get('attachment', None)
        self.code_ids = kwargs.get('code_ids', None)
        self.tag_details = kwargs.get('tag_details', None)
        self.document_url = kwargs.get('document_url', None)
        self.document_name = kwargs.get('document_name', None)
        self.title = kwargs.get('title', None)
        self.evidence_indicator_id = kwargs.get('evidence_indicator_id', None)
        self.created = kwargs.get('created', None)
        self.created_by = kwargs.get('created_by', None)
        self.modified = kwargs.get('modified', None)
        self.modified_by = kwargs.get('modified_by', None)
        self.savings = kwargs.get('savings', None)
        self.group_name = kwargs.get('group_name', None)
        self.group_path = kwargs.get('group_path', None)
        self.group_type = kwargs.get('group_type', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RepeaterNodeChild(Model):
    """RepeaterNodeChild.

    All required parameters must be populated in order to send to Azure.

    :param repeater_id: Required.
    :type repeater_id: long
    :param repeater_name:
    :type repeater_name: str
    :param repeater_serial_number: Required.
    :type repeater_serial_number: str
    """

    _validation = {
        'repeater_id': {'required': True},
        'repeater_serial_number': {'required': True, 'max_length': 8},
    }

    _attribute_map = {
        'repeater_id': {'key': 'RepeaterId', 'type': 'long'},
        'repeater_name': {'key': 'RepeaterName', 'type': 'str'},
        'repeater_serial_number': {'key': 'RepeaterSerialNumber', 'type': 'str'},
    }

    def __init__(self, *, repeater_id: int, repeater_serial_number: str, repeater_name: str=None, **kwargs) -> None:
        super(RepeaterNodeChild, self).__init__(**kwargs)
        self.repeater_id = repeater_id
        self.repeater_name = repeater_name
        self.repeater_serial_number = repeater_serial_number



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UpdateBearingsForGroupRequest(Model):
    """UpdateBearingsForGroupRequest.

    All required parameters must be populated in order to send to Azure.

    :param bearing_ids: Required.
    :type bearing_ids: list[str]
    """

    _validation = {
        'bearing_ids': {'required': True},
    }

    _attribute_map = {
        'bearing_ids': {'key': 'BearingIds', 'type': '[str]'},
    }

    def __init__(self, *, bearing_ids, **kwargs) -> None:
        super(UpdateBearingsForGroupRequest, self).__init__(**kwargs)
        self.bearing_ids = bearing_ids



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class NodeSettingOverview(Model):
    """NodeSettingOverview.

    :param update_interval:
    :type update_interval: ~smartdiagnostics_sdk.models.NodeSettingValues
    :param decimation_factor:
    :type decimation_factor: ~smartdiagnostics_sdk.models.NodeSettingValues
    :param operating_mode_pressure:
    :type operating_mode_pressure:
     ~smartdiagnostics_sdk.models.NodeSettingValues
    :param operating_mode_vibration:
    :type operating_mode_vibration:
     ~smartdiagnostics_sdk.models.NodeSettingValues
    :param number_of_samples:
    :type number_of_samples: ~smartdiagnostics_sdk.models.NodeSettingValues
    :param compression_type:
    :type compression_type: ~smartdiagnostics_sdk.models.NodeSettingValues
    """

    _attribute_map = {
        'update_interval': {'key': 'UpdateInterval', 'type': 'NodeSettingValues'},
        'decimation_factor': {'key': 'DecimationFactor', 'type': 'NodeSettingValues'},
        'operating_mode_pressure': {'key': 'OperatingModePressure', 'type': 'NodeSettingValues'},
        'operating_mode_vibration': {'key': 'OperatingModeVibration', 'type': 'NodeSettingValues'},
        'number_of_samples': {'key': 'NumberOfSamples', 'type': 'NodeSettingValues'},
        'compression_type': {'key': 'CompressionType', 'type': 'NodeSettingValues'},
    }

    def __init__(self, **kwargs):
        super(NodeSettingOverview, self).__init__(**kwargs)
        self.update_interval = kwargs.get('update_interval', None)
        self.decimation_factor = kwargs.get('decimation_factor', None)
        self.operating_mode_pressure = kwargs.get('operating_mode_pressure', None)
        self.operating_mode_vibration = kwargs.get('operating_mode_vibration', None)
        self.number_of_samples = kwargs.get('number_of_samples', None)
        self.compression_type = kwargs.get('compression_type', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CorporationIndustryChild(Model):
    """CorporationIndustryChild.

    All required parameters must be populated in order to send to Azure.

    :param industry_id: Required.
    :type industry_id: int
    :param industry_name: Required.
    :type industry_name: str
    """

    _validation = {
        'industry_id': {'required': True},
        'industry_name': {'required': True},
    }

    _attribute_map = {
        'industry_id': {'key': 'IndustryId', 'type': 'int'},
        'industry_name': {'key': 'IndustryName', 'type': 'str'},
    }

    def __init__(self, *, industry_id: int, industry_name: str, **kwargs) -> None:
        super(CorporationIndustryChild, self).__init__(**kwargs)
        self.industry_id = industry_id
        self.industry_name = industry_name



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MonitoringPointNodeChild(Model):
    """MonitoringPointNodeChild.

    :param node_id:
    :type node_id: long
    :param node_serial_number:
    :type node_serial_number: str
    :param node_nickname:
    :type node_nickname: str
    :param node_type_code: Possible values include: 'Invalid', 'KcfFlow',
     'KcfPressureVoltage', 'KcfPressureCurrent', 'KcfPower', 'KcfVibration',
     'KcfVibrationV1', 'KcfVoltage', 'KcfCurrent', 'KcfAtoDVoltage',
     'KcfAtoDCurrent', 'KcfOilQuality', 'Generic', 'KcfAgnostic',
     'KcfHumidity', 'KcfExtendedTemperatureVibration', 'KcfHubVibrationV1',
     'KcfHubAnalogAdapterV1'
    :type node_type_code: str or ~smartdiagnostics_sdk.models.enum
    """

    _attribute_map = {
        'node_id': {'key': 'NodeId', 'type': 'long'},
        'node_serial_number': {'key': 'NodeSerialNumber', 'type': 'str'},
        'node_nickname': {'key': 'NodeNickname', 'type': 'str'},
        'node_type_code': {'key': 'NodeTypeCode', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(MonitoringPointNodeChild, self).__init__(**kwargs)
        self.node_id = kwargs.get('node_id', None)
        self.node_serial_number = kwargs.get('node_serial_number', None)
        self.node_nickname = kwargs.get('node_nickname', None)
        self.node_type_code = kwargs.get('node_type_code', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class HubResponse(Model):
    """HubResponse.

    :param id:
    :type id: long
    :param receiver:
    :type receiver: ~smartdiagnostics_sdk.models.ReceiverChild
    :param location:
    :type location: ~smartdiagnostics_sdk.models.LocationChild
    :param corporation:
    :type corporation: ~smartdiagnostics_sdk.models.CorporationChild
    :param serial_number:
    :type serial_number: str
    :param nickname:
    :type nickname: str
    :param power_type_id: Possible values include: 'Unspecified', 'DC (24V)',
     'Battery', 'AC (120V)'
    :type power_type_id: str or ~smartdiagnostics_sdk.models.enum
    :param firmware_version:
    :type firmware_version: str
    :param hub_type_id: Possible values include: 'Unknown', 'Version 1
     (SevenPort)'
    :type hub_type_id: str or ~smartdiagnostics_sdk.models.enum
    :param created:
    :type created: datetime
    :param updated:
    :type updated: datetime
    :param packet_success_rate:
    :type packet_success_rate: float
    :param wireless_efficiency:
    :type wireless_efficiency: float
    :param is_online:
    :type is_online: bool
    :param triggering_enabled:
    :type triggering_enabled: bool
    :param ports:
    :type ports: list[~smartdiagnostics_sdk.models.HubPortChild]
    """

    _validation = {
        'serial_number': {'max_length': 16},
        'nickname': {'max_length': 50},
    }

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'long'},
        'receiver': {'key': 'Receiver', 'type': 'ReceiverChild'},
        'location': {'key': 'Location', 'type': 'LocationChild'},
        'corporation': {'key': 'Corporation', 'type': 'CorporationChild'},
        'serial_number': {'key': 'SerialNumber', 'type': 'str'},
        'nickname': {'key': 'Nickname', 'type': 'str'},
        'power_type_id': {'key': 'PowerTypeId', 'type': 'str'},
        'firmware_version': {'key': 'FirmwareVersion', 'type': 'str'},
        'hub_type_id': {'key': 'HubTypeId', 'type': 'str'},
        'created': {'key': 'Created', 'type': 'iso-8601'},
        'updated': {'key': 'Updated', 'type': 'iso-8601'},
        'packet_success_rate': {'key': 'PacketSuccessRate', 'type': 'float'},
        'wireless_efficiency': {'key': 'WirelessEfficiency', 'type': 'float'},
        'is_online': {'key': 'IsOnline', 'type': 'bool'},
        'triggering_enabled': {'key': 'TriggeringEnabled', 'type': 'bool'},
        'ports': {'key': 'Ports', 'type': '[HubPortChild]'},
    }

    def __init__(self, **kwargs):
        super(HubResponse, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.receiver = kwargs.get('receiver', None)
        self.location = kwargs.get('location', None)
        self.corporation = kwargs.get('corporation', None)
        self.serial_number = kwargs.get('serial_number', None)
        self.nickname = kwargs.get('nickname', None)
        self.power_type_id = kwargs.get('power_type_id', None)
        self.firmware_version = kwargs.get('firmware_version', None)
        self.hub_type_id = kwargs.get('hub_type_id', None)
        self.created = kwargs.get('created', None)
        self.updated = kwargs.get('updated', None)
        self.packet_success_rate = kwargs.get('packet_success_rate', None)
        self.wireless_efficiency = kwargs.get('wireless_efficiency', None)
        self.is_online = kwargs.get('is_online', None)
        self.triggering_enabled = kwargs.get('triggering_enabled', None)
        self.ports = kwargs.get('ports', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

try:
    from .location_child_py3 import LocationChild
    from .group_child_py3 import GroupChild
    from .indicator_child_py3 import IndicatorChild
    from .activity_code_child_py3 import ActivityCodeChild
    from .document_child_py3 import DocumentChild
    from .hierarchy_child_py3 import HierarchyChild
    from .activity_response_py3 import ActivityResponse
    from .paged_results_model_activity_response_py3 import PagedResultsModelActivityResponse
    from .problem_details_py3 import ProblemDetails
    from .activity_create_request_py3 import ActivityCreateRequest
    from .activity_update_request_py3 import ActivityUpdateRequest
    from .activity_category_response_py3 import ActivityCategoryResponse
    from .paged_results_model_activity_category_response_py3 import PagedResultsModelActivityCategoryResponse
    from .activity_code_response_py3 import ActivityCodeResponse
    from .paged_results_model_activity_code_response_py3 import PagedResultsModelActivityCodeResponse
    from .analytics_model_indicator_child_py3 import AnalyticsModelIndicatorChild
    from .property_child_py3 import PropertyChild
    from .analytics_model_related_model_child_py3 import AnalyticsModelRelatedModelChild
    from .user_child_py3 import UserChild
    from .corporation_child_py3 import CorporationChild
    from .trigger_child_py3 import TriggerChild
    from .analytics_model_response_py3 import AnalyticsModelResponse
    from .property_request_child_py3 import PropertyRequestChild
    from .analytics_model_update_request_py3 import AnalyticsModelUpdateRequest
    from .paged_results_model_analytics_model_response_py3 import PagedResultsModelAnalyticsModelResponse
    from .analytics_model_create_request_py3 import AnalyticsModelCreateRequest
    from .asset_type_child_py3 import AssetTypeChild
    from .asset_category_marker_child_py3 import AssetCategoryMarkerChild
    from .asset_category_child_py3 import AssetCategoryChild
    from .asset_size_child_py3 import AssetSizeChild
    from .asset_economics_child_py3 import AssetEconomicsChild
    from .asset_running_speed_child_py3 import AssetRunningSpeedChild
    from .asset_criticality_child_py3 import AssetCriticalityChild
    from .asset_drum_roll_child_py3 import AssetDrumRollChild
    from .parent_child_py3 import ParentChild
    from .descendant_child_py3 import DescendantChild
    from .tag_child_py3 import TagChild
    from .analytics_model_child_py3 import AnalyticsModelChild
    from .asset_response_py3 import AssetResponse
    from .asset_update_request_py3 import AssetUpdateRequest
    from .paged_results_model_asset_response_py3 import PagedResultsModelAssetResponse
    from .asset_create_request_py3 import AssetCreateRequest
    from .group_move_request_py3 import GroupMoveRequest
    from .group_status_response_py3 import GroupStatusResponse
    from .paged_results_model_group_status_response_py3 import PagedResultsModelGroupStatusResponse
    from .asset_category_with_size_child_py3 import AssetCategoryWithSizeChild
    from .asset_type_response_py3 import AssetTypeResponse
    from .paged_results_model_asset_type_response_py3 import PagedResultsModelAssetTypeResponse
    from .marker_response_py3 import MarkerResponse
    from .paged_results_model_marker_response_py3 import PagedResultsModelMarkerResponse
    from .marker_update_request_py3 import MarkerUpdateRequest
    from .release_ring_child_py3 import ReleaseRingChild
    from .targeted_software_release_child_py3 import TargetedSoftwareReleaseChild
    from .current_software_release_child_py3 import CurrentSoftwareReleaseChild
    from .hardware_revision_child_py3 import HardwareRevisionChild
    from .receiver_child_py3 import ReceiverChild
    from .base_station_response_py3 import BaseStationResponse
    from .base_station_update_request_py3 import BaseStationUpdateRequest
    from .paged_results_model_base_station_response_py3 import PagedResultsModelBaseStationResponse
    from .base_station_create_request_py3 import BaseStationCreateRequest
    from .bearing_response_py3 import BearingResponse
    from .paged_results_model_bearing_response_py3 import PagedResultsModelBearingResponse
    from .corporation_create_request_py3 import CorporationCreateRequest
    from .corporation_industry_child_py3 import CorporationIndustryChild
    from .corporation_response_py3 import CorporationResponse
    from .paged_results_model_corporation_response_py3 import PagedResultsModelCorporationResponse
    from .corporation_update_request_py3 import CorporationUpdateRequest
    from .roi_response_py3 import RoiResponse
    from .dashboard_type_child_py3 import DashboardTypeChild
    from .primary_corporation_child_py3 import PrimaryCorporationChild
    from .layout_child_py3 import LayoutChild
    from .widget_type_child_py3 import WidgetTypeChild
    from .widget_child_py3 import WidgetChild
    from .dashboard_widget_child_py3 import DashboardWidgetChild
    from .power_bi_report_child_py3 import PowerBiReportChild
    from .dashboard_response_py3 import DashboardResponse
    from .dashboard_widget_request_child_py3 import DashboardWidgetRequestChild
    from .dashboard_update_request_py3 import DashboardUpdateRequest
    from .paged_results_model_dashboard_response_py3 import PagedResultsModelDashboardResponse
    from .dashboard_create_request_py3 import DashboardCreateRequest
    from .widget_template_filter_child_py3 import WidgetTemplateFilterChild
    from .widget_template_child_py3 import WidgetTemplateChild
    from .dashboard_template_response_py3 import DashboardTemplateResponse
    from .paged_results_model_dashboard_template_response_py3 import PagedResultsModelDashboardTemplateResponse
    from .dashboard_permissions_update_request_py3 import DashboardPermissionsUpdateRequest
    from .time_range_model_v3_py3 import TimeRangeModelV3
    from .attachment_model_v3_py3 import AttachmentModelV3
    from .event_model_v3_py3 import EventModelV3
    from .file_response_py3 import FileResponse
    from .paged_results_model_file_response_py3 import PagedResultsModelFileResponse
    from .files_update_request_py3 import FilesUpdateRequest
    from .move_files_request_py3 import MoveFilesRequest
    from .files_error_py3 import FilesError
    from .move_files_response_py3 import MoveFilesResponse
    from .system_child_py3 import SystemChild
    from .indicator_filter_response_py3 import IndicatorFilterResponse
    from .indicator_filter_update_request_py3 import IndicatorFilterUpdateRequest
    from .paged_results_model_indicator_filter_response_py3 import PagedResultsModelIndicatorFilterResponse
    from .indicator_filter_create_request_py3 import IndicatorFilterCreateRequest
    from .external_notification_child_py3 import ExternalNotificationChild
    from .group_alerts_response_py3 import GroupAlertsResponse
    from .paged_results_model_group_alerts_response_py3 import PagedResultsModelGroupAlertsResponse
    from .group_analytics_model_response_py3 import GroupAnalyticsModelResponse
    from .set_property_child_py3 import SetPropertyChild
    from .group_analytics_model_update_request_py3 import GroupAnalyticsModelUpdateRequest
    from .paged_results_model_group_analytics_model_response_py3 import PagedResultsModelGroupAnalyticsModelResponse
    from .group_analytics_model_add_request_py3 import GroupAnalyticsModelAddRequest
    from .marker_child_py3 import MarkerChild
    from .custom_marker_child_py3 import CustomMarkerChild
    from .frequency_domain_setting_child_py3 import FrequencyDomainSettingChild
    from .spectrum_chart_settings_create_request_py3 import SpectrumChartSettingsCreateRequest
    from .spectrum_chart_settings_response_py3 import SpectrumChartSettingsResponse
    from .update_bearings_for_group_request_py3 import UpdateBearingsForGroupRequest
    from .monitoring_point_overview_node_child_py3 import MonitoringPointOverviewNodeChild
    from .overview_hierarchy_child_py3 import OverviewHierarchyChild
    from .node_setting_values_py3 import NodeSettingValues
    from .node_setting_overview_py3 import NodeSettingOverview
    from .monitoring_point_overview_response_py3 import MonitoringPointOverviewResponse
    from .paged_results_model_monitoring_point_overview_response_py3 import PagedResultsModelMonitoringPointOverviewResponse
    from .hardware_model_v3_py3 import HardwareModelV3
    from .hardware_event_model_v3_py3 import HardwareEventModelV3
    from .paged_results_model_hardware_event_model_v3_py3 import PagedResultsModelHardwareEventModelV3
    from .hardware_status_child_py3 import HardwareStatusChild
    from .hardware_status_response_py3 import HardwareStatusResponse
    from .node_setting_child_py3 import NodeSettingChild
    from .long_burst_request_child_py3 import LongBurstRequestChild
    from .hub_node_child_py3 import HubNodeChild
    from .hub_port_child_py3 import HubPortChild
    from .hub_response_py3 import HubResponse
    from .paged_results_model_hub_response_py3 import PagedResultsModelHubResponse
    from .indicator_group_response_py3 import IndicatorGroupResponse
    from .indicator_group_update_request_py3 import IndicatorGroupUpdateRequest
    from .paged_results_model_indicator_group_response_py3 import PagedResultsModelIndicatorGroupResponse
    from .indicator_group_create_request_py3 import IndicatorGroupCreateRequest
    from .alarm_definition_child_py3 import AlarmDefinitionChild
    from .band_definition_child_py3 import BandDefinitionChild
    from .baseline_indicator_child_py3 import BaselineIndicatorChild
    from .indicator_response_py3 import IndicatorResponse
    from .paged_results_model_indicator_response_py3 import PagedResultsModelIndicatorResponse
    from .indicator_alarm_state_response_py3 import IndicatorAlarmStateResponse
    from .indicator_types_response_py3 import IndicatorTypesResponse
    from .paged_results_model_indicator_types_response_py3 import PagedResultsModelIndicatorTypesResponse
    from .node_status_child_py3 import NodeStatusChild
    from .install_nodes_status_child_py3 import InstallNodesStatusChild
    from .install_response_py3 import InstallResponse
    from .paged_results_model_install_response_py3 import PagedResultsModelInstallResponse
    from .install_update_request_py3 import InstallUpdateRequest
    from .install_modify_users_request_py3 import InstallModifyUsersRequest
    from .install_add_user_response_py3 import InstallAddUserResponse
    from .install_node_status_child_py3 import InstallNodeStatusChild
    from .install_node_response_py3 import InstallNodeResponse
    from .paged_results_model_install_node_response_py3 import PagedResultsModelInstallNodeResponse
    from .install_node_update_request_py3 import InstallNodeUpdateRequest
    from .location_settings_child_py3 import LocationSettingsChild
    from .location_response_py3 import LocationResponse
    from .paged_results_model_location_response_py3 import PagedResultsModelLocationResponse
    from .location_create_request_py3 import LocationCreateRequest
    from .node_child_py3 import NodeChild
    from .bearing_child_py3 import BearingChild
    from .monitoring_point_response_py3 import MonitoringPointResponse
    from .paged_results_model_monitoring_point_response_py3 import PagedResultsModelMonitoringPointResponse
    from .monitoring_point_child_py3 import MonitoringPointChild
    from .monitoring_point_node_child_py3 import MonitoringPointNodeChild
    from .monitoring_point_assignment_response_py3 import MonitoringPointAssignmentResponse
    from .paged_results_model_monitoring_point_assignment_response_py3 import PagedResultsModelMonitoringPointAssignmentResponse
    from .monitoring_point_type_code_model_py3 import MonitoringPointTypeCodeModel
    from .hub_child_py3 import HubChild
    from .base_station_node_child_py3 import BaseStationNodeChild
    from .repeater_node_child_py3 import RepeaterNodeChild
    from .node_response_py3 import NodeResponse
    from .paged_results_model_node_response_py3 import PagedResultsModelNodeResponse
    from .pictures_model_v3_py3 import PicturesModelV3
    from .paged_results_model_pictures_model_v3_py3 import PagedResultsModelPicturesModelV3
    from .property_response_py3 import PropertyResponse
    from .paged_results_model_property_response_py3 import PagedResultsModelPropertyResponse
    from .receiver_response_py3 import ReceiverResponse
    from .paged_results_model_receiver_response_py3 import PagedResultsModelReceiverResponse
    from .repeater_model_v3_py3 import RepeaterModelV3
    from .paged_results_model_repeater_model_v3_py3 import PagedResultsModelRepeaterModelV3
    from .statistics_report_request_py3 import StatisticsReportRequest
    from .heatmap_report_request_py3 import HeatmapReportRequest
    from .job_model_v3_py3 import JobModelV3
    from .sub_system_response_py3 import SubSystemResponse
    from .sub_system_update_request_py3 import SubSystemUpdateRequest
    from .paged_results_model_sub_system_response_py3 import PagedResultsModelSubSystemResponse
    from .sub_system_create_request_py3 import SubSystemCreateRequest
    from .system_create_request_py3 import SystemCreateRequest
    from .base_station_child_py3 import BaseStationChild
    from .system_response_py3 import SystemResponse
    from .paged_results_model_system_response_py3 import PagedResultsModelSystemResponse
    from .system_update_request_py3 import SystemUpdateRequest
    from .assets_status_count_child_py3 import AssetsStatusCountChild
    from .assets_status_percentage_child_py3 import AssetsStatusPercentageChild
    from .system_assets_status_summary_response_py3 import SystemAssetsStatusSummaryResponse
    from .paged_results_model_system_assets_status_summary_response_py3 import PagedResultsModelSystemAssetsStatusSummaryResponse
    from .system_overview_response_py3 import SystemOverviewResponse
    from .paged_results_model_system_overview_response_py3 import PagedResultsModelSystemOverviewResponse
    from .tag_response_py3 import TagResponse
    from .paged_results_model_tag_response_py3 import PagedResultsModelTagResponse
    from .tag_create_request_py3 import TagCreateRequest
    from .tag_update_request_py3 import TagUpdateRequest
    from .token_exchange_request_py3 import TokenExchangeRequest
    from .token_exchange_response_py3 import TokenExchangeResponse
    from .tree_item_response_py3 import TreeItemResponse
    from .paged_results_model_tree_item_response_py3 import PagedResultsModelTreeItemResponse
    from .tree_item_child_py3 import TreeItemChild
    from .tree_item_available_asset_class_response_py3 import TreeItemAvailableAssetClassResponse
    from .paged_results_model_tree_item_available_asset_class_response_py3 import PagedResultsModelTreeItemAvailableAssetClassResponse
    from .user_corporation_child_py3 import UserCorporationChild
    from .user_location_child_py3 import UserLocationChild
    from .profile_child_py3 import ProfileChild
    from .current_user_response_py3 import CurrentUserResponse
    from .personal_access_token_response_py3 import PersonalAccessTokenResponse
    from .paged_results_model_personal_access_token_response_py3 import PagedResultsModelPersonalAccessTokenResponse
    from .personal_access_token_create_request_py3 import PersonalAccessTokenCreateRequest
    from .personal_access_token_create_response_py3 import PersonalAccessTokenCreateResponse
    from .personal_access_token_update_request_py3 import PersonalAccessTokenUpdateRequest
except (SyntaxError, ImportError):
    from .location_child import LocationChild
    from .group_child import GroupChild
    from .indicator_child import IndicatorChild
    from .activity_code_child import ActivityCodeChild
    from .document_child import DocumentChild
    from .hierarchy_child import HierarchyChild
    from .activity_response import ActivityResponse
    from .paged_results_model_activity_response import PagedResultsModelActivityResponse
    from .problem_details import ProblemDetails
    from .activity_create_request import ActivityCreateRequest
    from .activity_update_request import ActivityUpdateRequest
    from .activity_category_response import ActivityCategoryResponse
    from .paged_results_model_activity_category_response import PagedResultsModelActivityCategoryResponse
    from .activity_code_response import ActivityCodeResponse
    from .paged_results_model_activity_code_response import PagedResultsModelActivityCodeResponse
    from .analytics_model_indicator_child import AnalyticsModelIndicatorChild
    from .property_child import PropertyChild
    from .analytics_model_related_model_child import AnalyticsModelRelatedModelChild
    from .user_child import UserChild
    from .corporation_child import CorporationChild
    from .trigger_child import TriggerChild
    from .analytics_model_response import AnalyticsModelResponse
    from .property_request_child import PropertyRequestChild
    from .analytics_model_update_request import AnalyticsModelUpdateRequest
    from .paged_results_model_analytics_model_response import PagedResultsModelAnalyticsModelResponse
    from .analytics_model_create_request import AnalyticsModelCreateRequest
    from .asset_type_child import AssetTypeChild
    from .asset_category_marker_child import AssetCategoryMarkerChild
    from .asset_category_child import AssetCategoryChild
    from .asset_size_child import AssetSizeChild
    from .asset_economics_child import AssetEconomicsChild
    from .asset_running_speed_child import AssetRunningSpeedChild
    from .asset_criticality_child import AssetCriticalityChild
    from .asset_drum_roll_child import AssetDrumRollChild
    from .parent_child import ParentChild
    from .descendant_child import DescendantChild
    from .tag_child import TagChild
    from .analytics_model_child import AnalyticsModelChild
    from .asset_response import AssetResponse
    from .asset_update_request import AssetUpdateRequest
    from .paged_results_model_asset_response import PagedResultsModelAssetResponse
    from .asset_create_request import AssetCreateRequest
    from .group_move_request import GroupMoveRequest
    from .group_status_response import GroupStatusResponse
    from .paged_results_model_group_status_response import PagedResultsModelGroupStatusResponse
    from .asset_category_with_size_child import AssetCategoryWithSizeChild
    from .asset_type_response import AssetTypeResponse
    from .paged_results_model_asset_type_response import PagedResultsModelAssetTypeResponse
    from .marker_response import MarkerResponse
    from .paged_results_model_marker_response import PagedResultsModelMarkerResponse
    from .marker_update_request import MarkerUpdateRequest
    from .release_ring_child import ReleaseRingChild
    from .targeted_software_release_child import TargetedSoftwareReleaseChild
    from .current_software_release_child import CurrentSoftwareReleaseChild
    from .hardware_revision_child import HardwareRevisionChild
    from .receiver_child import ReceiverChild
    from .base_station_response import BaseStationResponse
    from .base_station_update_request import BaseStationUpdateRequest
    from .paged_results_model_base_station_response import PagedResultsModelBaseStationResponse
    from .base_station_create_request import BaseStationCreateRequest
    from .bearing_response import BearingResponse
    from .paged_results_model_bearing_response import PagedResultsModelBearingResponse
    from .corporation_create_request import CorporationCreateRequest
    from .corporation_industry_child import CorporationIndustryChild
    from .corporation_response import CorporationResponse
    from .paged_results_model_corporation_response import PagedResultsModelCorporationResponse
    from .corporation_update_request import CorporationUpdateRequest
    from .roi_response import RoiResponse
    from .dashboard_type_child import DashboardTypeChild
    from .primary_corporation_child import PrimaryCorporationChild
    from .layout_child import LayoutChild
    from .widget_type_child import WidgetTypeChild
    from .widget_child import WidgetChild
    from .dashboard_widget_child import DashboardWidgetChild
    from .power_bi_report_child import PowerBiReportChild
    from .dashboard_response import DashboardResponse
    from .dashboard_widget_request_child import DashboardWidgetRequestChild
    from .dashboard_update_request import DashboardUpdateRequest
    from .paged_results_model_dashboard_response import PagedResultsModelDashboardResponse
    from .dashboard_create_request import DashboardCreateRequest
    from .widget_template_filter_child import WidgetTemplateFilterChild
    from .widget_template_child import WidgetTemplateChild
    from .dashboard_template_response import DashboardTemplateResponse
    from .paged_results_model_dashboard_template_response import PagedResultsModelDashboardTemplateResponse
    from .dashboard_permissions_update_request import DashboardPermissionsUpdateRequest
    from .time_range_model_v3 import TimeRangeModelV3
    from .attachment_model_v3 import AttachmentModelV3
    from .event_model_v3 import EventModelV3
    from .file_response import FileResponse
    from .paged_results_model_file_response import PagedResultsModelFileResponse
    from .files_update_request import FilesUpdateRequest
    from .move_files_request import MoveFilesRequest
    from .files_error import FilesError
    from .move_files_response import MoveFilesResponse
    from .system_child import SystemChild
    from .indicator_filter_response import IndicatorFilterResponse
    from .indicator_filter_update_request import IndicatorFilterUpdateRequest
    from .paged_results_model_indicator_filter_response import PagedResultsModelIndicatorFilterResponse
    from .indicator_filter_create_request import IndicatorFilterCreateRequest
    from .external_notification_child import ExternalNotificationChild
    from .group_alerts_response import GroupAlertsResponse
    from .paged_results_model_group_alerts_response import PagedResultsModelGroupAlertsResponse
    from .group_analytics_model_response import GroupAnalyticsModelResponse
    from .set_property_child import SetPropertyChild
    from .group_analytics_model_update_request import GroupAnalyticsModelUpdateRequest
    from .paged_results_model_group_analytics_model_response import PagedResultsModelGroupAnalyticsModelResponse
    from .group_analytics_model_add_request import GroupAnalyticsModelAddRequest
    from .marker_child import MarkerChild
    from .custom_marker_child import CustomMarkerChild
    from .frequency_domain_setting_child import FrequencyDomainSettingChild
    from .spectrum_chart_settings_create_request import SpectrumChartSettingsCreateRequest
    from .spectrum_chart_settings_response import SpectrumChartSettingsResponse
    from .update_bearings_for_group_request import UpdateBearingsForGroupRequest
    from .monitoring_point_overview_node_child import MonitoringPointOverviewNodeChild
    from .overview_hierarchy_child import OverviewHierarchyChild
    from .node_setting_values import NodeSettingValues
    from .node_setting_overview import NodeSettingOverview
    from .monitoring_point_overview_response import MonitoringPointOverviewResponse
    from .paged_results_model_monitoring_point_overview_response import PagedResultsModelMonitoringPointOverviewResponse
    from .hardware_model_v3 import HardwareModelV3
    from .hardware_event_model_v3 import HardwareEventModelV3
    from .paged_results_model_hardware_event_model_v3 import PagedResultsModelHardwareEventModelV3
    from .hardware_status_child import HardwareStatusChild
    from .hardware_status_response import HardwareStatusResponse
    from .node_setting_child import NodeSettingChild
    from .long_burst_request_child import LongBurstRequestChild
    from .hub_node_child import HubNodeChild
    from .hub_port_child import HubPortChild
    from .hub_response import HubResponse
    from .paged_results_model_hub_response import PagedResultsModelHubResponse
    from .indicator_group_response import IndicatorGroupResponse
    from .indicator_group_update_request import IndicatorGroupUpdateRequest
    from .paged_results_model_indicator_group_response import PagedResultsModelIndicatorGroupResponse
    from .indicator_group_create_request import IndicatorGroupCreateRequest
    from .alarm_definition_child import AlarmDefinitionChild
    from .band_definition_child import BandDefinitionChild
    from .baseline_indicator_child import BaselineIndicatorChild
    from .indicator_response import IndicatorResponse
    from .paged_results_model_indicator_response import PagedResultsModelIndicatorResponse
    from .indicator_alarm_state_response import IndicatorAlarmStateResponse
    from .indicator_types_response import IndicatorTypesResponse
    from .paged_results_model_indicator_types_response import PagedResultsModelIndicatorTypesResponse
    from .node_status_child import NodeStatusChild
    from .install_nodes_status_child import InstallNodesStatusChild
    from .install_response import InstallResponse
    from .paged_results_model_install_response import PagedResultsModelInstallResponse
    from .install_update_request import InstallUpdateRequest
    from .install_modify_users_request import InstallModifyUsersRequest
    from .install_add_user_response import InstallAddUserResponse
    from .install_node_status_child import InstallNodeStatusChild
    from .install_node_response import InstallNodeResponse
    from .paged_results_model_install_node_response import PagedResultsModelInstallNodeResponse
    from .install_node_update_request import InstallNodeUpdateRequest
    from .location_settings_child import LocationSettingsChild
    from .location_response import LocationResponse
    from .paged_results_model_location_response import PagedResultsModelLocationResponse
    from .location_create_request import LocationCreateRequest
    from .node_child import NodeChild
    from .bearing_child import BearingChild
    from .monitoring_point_response import MonitoringPointResponse
    from .paged_results_model_monitoring_point_response import PagedResultsModelMonitoringPointResponse
    from .monitoring_point_child import MonitoringPointChild
    from .monitoring_point_node_child import MonitoringPointNodeChild
    from .monitoring_point_assignment_response import MonitoringPointAssignmentResponse
    from .paged_results_model_monitoring_point_assignment_response import PagedResultsModelMonitoringPointAssignmentResponse
    from .monitoring_point_type_code_model import MonitoringPointTypeCodeModel
    from .hub_child import HubChild
    from .base_station_node_child import BaseStationNodeChild
    from .repeater_node_child import RepeaterNodeChild
    from .node_response import NodeResponse
    from .paged_results_model_node_response import PagedResultsModelNodeResponse
    from .pictures_model_v3 import PicturesModelV3
    from .paged_results_model_pictures_model_v3 import PagedResultsModelPicturesModelV3
    from .property_response import PropertyResponse
    from .paged_results_model_property_response import PagedResultsModelPropertyResponse
    from .receiver_response import ReceiverResponse
    from .paged_results_model_receiver_response import PagedResultsModelReceiverResponse
    from .repeater_model_v3 import RepeaterModelV3
    from .paged_results_model_repeater_model_v3 import PagedResultsModelRepeaterModelV3
    from .statistics_report_request import StatisticsReportRequest
    from .heatmap_report_request import HeatmapReportRequest
    from .job_model_v3 import JobModelV3
    from .sub_system_response import SubSystemResponse
    from .sub_system_update_request import SubSystemUpdateRequest
    from .paged_results_model_sub_system_response import PagedResultsModelSubSystemResponse
    from .sub_system_create_request import SubSystemCreateRequest
    from .system_create_request import SystemCreateRequest
    from .base_station_child import BaseStationChild
    from .system_response import SystemResponse
    from .paged_results_model_system_response import PagedResultsModelSystemResponse
    from .system_update_request import SystemUpdateRequest
    from .assets_status_count_child import AssetsStatusCountChild
    from .assets_status_percentage_child import AssetsStatusPercentageChild
    from .system_assets_status_summary_response import SystemAssetsStatusSummaryResponse
    from .paged_results_model_system_assets_status_summary_response import PagedResultsModelSystemAssetsStatusSummaryResponse
    from .system_overview_response import SystemOverviewResponse
    from .paged_results_model_system_overview_response import PagedResultsModelSystemOverviewResponse
    from .tag_response import TagResponse
    from .paged_results_model_tag_response import PagedResultsModelTagResponse
    from .tag_create_request import TagCreateRequest
    from .tag_update_request import TagUpdateRequest
    from .token_exchange_request import TokenExchangeRequest
    from .token_exchange_response import TokenExchangeResponse
    from .tree_item_response import TreeItemResponse
    from .paged_results_model_tree_item_response import PagedResultsModelTreeItemResponse
    from .tree_item_child import TreeItemChild
    from .tree_item_available_asset_class_response import TreeItemAvailableAssetClassResponse
    from .paged_results_model_tree_item_available_asset_class_response import PagedResultsModelTreeItemAvailableAssetClassResponse
    from .user_corporation_child import UserCorporationChild
    from .user_location_child import UserLocationChild
    from .profile_child import ProfileChild
    from .current_user_response import CurrentUserResponse
    from .personal_access_token_response import PersonalAccessTokenResponse
    from .paged_results_model_personal_access_token_response import PagedResultsModelPersonalAccessTokenResponse
    from .personal_access_token_create_request import PersonalAccessTokenCreateRequest
    from .personal_access_token_create_response import PersonalAccessTokenCreateResponse
    from .personal_access_token_update_request import PersonalAccessTokenUpdateRequest

__all__ = [
    'LocationChild',
    'GroupChild',
    'IndicatorChild',
    'ActivityCodeChild',
    'DocumentChild',
    'HierarchyChild',
    'ActivityResponse',
    'PagedResultsModelActivityResponse',
    'ProblemDetails',
    'ActivityCreateRequest',
    'ActivityUpdateRequest',
    'ActivityCategoryResponse',
    'PagedResultsModelActivityCategoryResponse',
    'ActivityCodeResponse',
    'PagedResultsModelActivityCodeResponse',
    'AnalyticsModelIndicatorChild',
    'PropertyChild',
    'AnalyticsModelRelatedModelChild',
    'UserChild',
    'CorporationChild',
    'TriggerChild',
    'AnalyticsModelResponse',
    'PropertyRequestChild',
    'AnalyticsModelUpdateRequest',
    'PagedResultsModelAnalyticsModelResponse',
    'AnalyticsModelCreateRequest',
    'AssetTypeChild',
    'AssetCategoryMarkerChild',
    'AssetCategoryChild',
    'AssetSizeChild',
    'AssetEconomicsChild',
    'AssetRunningSpeedChild',
    'AssetCriticalityChild',
    'AssetDrumRollChild',
    'ParentChild',
    'DescendantChild',
    'TagChild',
    'AnalyticsModelChild',
    'AssetResponse',
    'AssetUpdateRequest',
    'PagedResultsModelAssetResponse',
    'AssetCreateRequest',
    'GroupMoveRequest',
    'GroupStatusResponse',
    'PagedResultsModelGroupStatusResponse',
    'AssetCategoryWithSizeChild',
    'AssetTypeResponse',
    'PagedResultsModelAssetTypeResponse',
    'MarkerResponse',
    'PagedResultsModelMarkerResponse',
    'MarkerUpdateRequest',
    'ReleaseRingChild',
    'TargetedSoftwareReleaseChild',
    'CurrentSoftwareReleaseChild',
    'HardwareRevisionChild',
    'ReceiverChild',
    'BaseStationResponse',
    'BaseStationUpdateRequest',
    'PagedResultsModelBaseStationResponse',
    'BaseStationCreateRequest',
    'BearingResponse',
    'PagedResultsModelBearingResponse',
    'CorporationCreateRequest',
    'CorporationIndustryChild',
    'CorporationResponse',
    'PagedResultsModelCorporationResponse',
    'CorporationUpdateRequest',
    'RoiResponse',
    'DashboardTypeChild',
    'PrimaryCorporationChild',
    'LayoutChild',
    'WidgetTypeChild',
    'WidgetChild',
    'DashboardWidgetChild',
    'PowerBiReportChild',
    'DashboardResponse',
    'DashboardWidgetRequestChild',
    'DashboardUpdateRequest',
    'PagedResultsModelDashboardResponse',
    'DashboardCreateRequest',
    'WidgetTemplateFilterChild',
    'WidgetTemplateChild',
    'DashboardTemplateResponse',
    'PagedResultsModelDashboardTemplateResponse',
    'DashboardPermissionsUpdateRequest',
    'TimeRangeModelV3',
    'AttachmentModelV3',
    'EventModelV3',
    'FileResponse',
    'PagedResultsModelFileResponse',
    'FilesUpdateRequest',
    'MoveFilesRequest',
    'FilesError',
    'MoveFilesResponse',
    'SystemChild',
    'IndicatorFilterResponse',
    'IndicatorFilterUpdateRequest',
    'PagedResultsModelIndicatorFilterResponse',
    'IndicatorFilterCreateRequest',
    'ExternalNotificationChild',
    'GroupAlertsResponse',
    'PagedResultsModelGroupAlertsResponse',
    'GroupAnalyticsModelResponse',
    'SetPropertyChild',
    'GroupAnalyticsModelUpdateRequest',
    'PagedResultsModelGroupAnalyticsModelResponse',
    'GroupAnalyticsModelAddRequest',
    'MarkerChild',
    'CustomMarkerChild',
    'FrequencyDomainSettingChild',
    'SpectrumChartSettingsCreateRequest',
    'SpectrumChartSettingsResponse',
    'UpdateBearingsForGroupRequest',
    'MonitoringPointOverviewNodeChild',
    'OverviewHierarchyChild',
    'NodeSettingValues',
    'NodeSettingOverview',
    'MonitoringPointOverviewResponse',
    'PagedResultsModelMonitoringPointOverviewResponse',
    'HardwareModelV3',
    'HardwareEventModelV3',
    'PagedResultsModelHardwareEventModelV3',
    'HardwareStatusChild',
    'HardwareStatusResponse',
    'NodeSettingChild',
    'LongBurstRequestChild',
    'HubNodeChild',
    'HubPortChild',
    'HubResponse',
    'PagedResultsModelHubResponse',
    'IndicatorGroupResponse',
    'IndicatorGroupUpdateRequest',
    'PagedResultsModelIndicatorGroupResponse',
    'IndicatorGroupCreateRequest',
    'AlarmDefinitionChild',
    'BandDefinitionChild',
    'BaselineIndicatorChild',
    'IndicatorResponse',
    'PagedResultsModelIndicatorResponse',
    'IndicatorAlarmStateResponse',
    'IndicatorTypesResponse',
    'PagedResultsModelIndicatorTypesResponse',
    'NodeStatusChild',
    'InstallNodesStatusChild',
    'InstallResponse',
    'PagedResultsModelInstallResponse',
    'InstallUpdateRequest',
    'InstallModifyUsersRequest',
    'InstallAddUserResponse',
    'InstallNodeStatusChild',
    'InstallNodeResponse',
    'PagedResultsModelInstallNodeResponse',
    'InstallNodeUpdateRequest',
    'LocationSettingsChild',
    'LocationResponse',
    'PagedResultsModelLocationResponse',
    'LocationCreateRequest',
    'NodeChild',
    'BearingChild',
    'MonitoringPointResponse',
    'PagedResultsModelMonitoringPointResponse',
    'MonitoringPointChild',
    'MonitoringPointNodeChild',
    'MonitoringPointAssignmentResponse',
    'PagedResultsModelMonitoringPointAssignmentResponse',
    'MonitoringPointTypeCodeModel',
    'HubChild',
    'BaseStationNodeChild',
    'RepeaterNodeChild',
    'NodeResponse',
    'PagedResultsModelNodeResponse',
    'PicturesModelV3',
    'PagedResultsModelPicturesModelV3',
    'PropertyResponse',
    'PagedResultsModelPropertyResponse',
    'ReceiverResponse',
    'PagedResultsModelReceiverResponse',
    'RepeaterModelV3',
    'PagedResultsModelRepeaterModelV3',
    'StatisticsReportRequest',
    'HeatmapReportRequest',
    'JobModelV3',
    'SubSystemResponse',
    'SubSystemUpdateRequest',
    'PagedResultsModelSubSystemResponse',
    'SubSystemCreateRequest',
    'SystemCreateRequest',
    'BaseStationChild',
    'SystemResponse',
    'PagedResultsModelSystemResponse',
    'SystemUpdateRequest',
    'AssetsStatusCountChild',
    'AssetsStatusPercentageChild',
    'SystemAssetsStatusSummaryResponse',
    'PagedResultsModelSystemAssetsStatusSummaryResponse',
    'SystemOverviewResponse',
    'PagedResultsModelSystemOverviewResponse',
    'TagResponse',
    'PagedResultsModelTagResponse',
    'TagCreateRequest',
    'TagUpdateRequest',
    'TokenExchangeRequest',
    'TokenExchangeResponse',
    'TreeItemResponse',
    'PagedResultsModelTreeItemResponse',
    'TreeItemChild',
    'TreeItemAvailableAssetClassResponse',
    'PagedResultsModelTreeItemAvailableAssetClassResponse',
    'UserCorporationChild',
    'UserLocationChild',
    'ProfileChild',
    'CurrentUserResponse',
    'PersonalAccessTokenResponse',
    'PagedResultsModelPersonalAccessTokenResponse',
    'PersonalAccessTokenCreateRequest',
    'PersonalAccessTokenCreateResponse',
    'PersonalAccessTokenUpdateRequest',
]



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class IndicatorChild(Model):
    """IndicatorChild.

    :param indicator_id:
    :type indicator_id: str
    :param indicator_name:
    :type indicator_name: str
    :param indicator_abbreviation:
    :type indicator_abbreviation: str
    """

    _attribute_map = {
        'indicator_id': {'key': 'IndicatorId', 'type': 'str'},
        'indicator_name': {'key': 'IndicatorName', 'type': 'str'},
        'indicator_abbreviation': {'key': 'IndicatorAbbreviation', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(IndicatorChild, self).__init__(**kwargs)
        self.indicator_id = kwargs.get('indicator_id', None)
        self.indicator_name = kwargs.get('indicator_name', None)
        self.indicator_abbreviation = kwargs.get('indicator_abbreviation', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class InstallNodeStatusChild(Model):
    """InstallNodeStatusChild.

    :param status_id: The corresponding StatusId
    :type status_id: long
    :param status: The textual description of the Status
    :type status: str
    :param status_date: The DateTime that the current status was set as part
     of an install activity
    :type status_date: datetime
    :param status_note: A brief note about the installation of the node,
     typically used when
     something prevents a node from being installed to keep records
    :type status_note: str
    :param install_user: The user that set the current install status
    :type install_user: str
    """

    _attribute_map = {
        'status_id': {'key': 'StatusId', 'type': 'long'},
        'status': {'key': 'Status', 'type': 'str'},
        'status_date': {'key': 'StatusDate', 'type': 'iso-8601'},
        'status_note': {'key': 'StatusNote', 'type': 'str'},
        'install_user': {'key': 'InstallUser', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(InstallNodeStatusChild, self).__init__(**kwargs)
        self.status_id = kwargs.get('status_id', None)
        self.status = kwargs.get('status', None)
        self.status_date = kwargs.get('status_date', None)
        self.status_note = kwargs.get('status_note', None)
        self.install_user = kwargs.get('install_user', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TagChild(Model):
    """TagChild.

    :param tag_id:
    :type tag_id: str
    :param tag_name:
    :type tag_name: str
    :param tag_category: Possible values include: 'General', 'Components',
     'Make', 'Model', 'Location', 'Orientation', 'Asset', 'AssetCode',
     'Picture'
    :type tag_category: str or ~smartdiagnostics_sdk.models.enum
    """

    _validation = {
        'tag_name': {'max_length': 50},
    }

    _attribute_map = {
        'tag_id': {'key': 'TagId', 'type': 'str'},
        'tag_name': {'key': 'TagName', 'type': 'str'},
        'tag_category': {'key': 'TagCategory', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(TagChild, self).__init__(**kwargs)
        self.tag_id = kwargs.get('tag_id', None)
        self.tag_name = kwargs.get('tag_name', None)
        self.tag_category = kwargs.get('tag_category', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AssetEconomicsChild(Model):
    """AssetEconomicsChild.

    :param asset_cost:
    :type asset_cost: float
    :param date_installed:
    :type date_installed: datetime
    :param annual_run_time:
    :type annual_run_time: float
    :param lost_production_cost:
    :type lost_production_cost: float
    :param overhaul_cost:
    :type overhaul_cost: float
    :param power_consumption:
    :type power_consumption: float
    :param life_expectancy:
    :type life_expectancy: float
    :param unscheduled_downtime:
    :type unscheduled_downtime: float
    """

    _attribute_map = {
        'asset_cost': {'key': 'AssetCost', 'type': 'float'},
        'date_installed': {'key': 'DateInstalled', 'type': 'iso-8601'},
        'annual_run_time': {'key': 'AnnualRunTime', 'type': 'float'},
        'lost_production_cost': {'key': 'LostProductionCost', 'type': 'float'},
        'overhaul_cost': {'key': 'OverhaulCost', 'type': 'float'},
        'power_consumption': {'key': 'PowerConsumption', 'type': 'float'},
        'life_expectancy': {'key': 'LifeExpectancy', 'type': 'float'},
        'unscheduled_downtime': {'key': 'UnscheduledDowntime', 'type': 'float'},
    }

    def __init__(self, **kwargs):
        super(AssetEconomicsChild, self).__init__(**kwargs)
        self.asset_cost = kwargs.get('asset_cost', None)
        self.date_installed = kwargs.get('date_installed', None)
        self.annual_run_time = kwargs.get('annual_run_time', None)
        self.lost_production_cost = kwargs.get('lost_production_cost', None)
        self.overhaul_cost = kwargs.get('overhaul_cost', None)
        self.power_consumption = kwargs.get('power_consumption', None)
        self.life_expectancy = kwargs.get('life_expectancy', None)
        self.unscheduled_downtime = kwargs.get('unscheduled_downtime', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class LocationResponse(Model):
    """LocationResponse.

    All required parameters must be populated in order to send to Azure.

    :param id: Required.
    :type id: str
    :param name: Required.
    :type name: str
    :param abbreviation:
    :type abbreviation: str
    :param active:
    :type active: bool
    :param created:
    :type created: datetime
    :param site_ids:
    :type site_ids: list[str]
    :param settings:
    :type settings: ~smartdiagnostics_sdk.models.LocationSettingsChild
    :param corporation:
    :type corporation: ~smartdiagnostics_sdk.models.PrimaryCorporationChild
    :param systems:
    :type systems: list[~smartdiagnostics_sdk.models.SystemChild]
    """

    _validation = {
        'id': {'required': True},
        'name': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'str'},
        'name': {'key': 'Name', 'type': 'str'},
        'abbreviation': {'key': 'Abbreviation', 'type': 'str'},
        'active': {'key': 'Active', 'type': 'bool'},
        'created': {'key': 'Created', 'type': 'iso-8601'},
        'site_ids': {'key': 'SiteIds', 'type': '[str]'},
        'settings': {'key': 'Settings', 'type': 'LocationSettingsChild'},
        'corporation': {'key': 'Corporation', 'type': 'PrimaryCorporationChild'},
        'systems': {'key': 'Systems', 'type': '[SystemChild]'},
    }

    def __init__(self, **kwargs):
        super(LocationResponse, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.name = kwargs.get('name', None)
        self.abbreviation = kwargs.get('abbreviation', None)
        self.active = kwargs.get('active', None)
        self.created = kwargs.get('created', None)
        self.site_ids = kwargs.get('site_ids', None)
        self.settings = kwargs.get('settings', None)
        self.corporation = kwargs.get('corporation', None)
        self.systems = kwargs.get('systems', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CustomMarkerChild(Model):
    """CustomMarkerChild.

    All required parameters must be populated in order to send to Azure.

    :param custom_marker_id: Required.
    :type custom_marker_id: str
    :param custom_marker_name:
    :type custom_marker_name: str
    :param custom_marker_show_harmonics: Required.
    :type custom_marker_show_harmonics: bool
    :param custom_marker_show_side_bands: Required.
    :type custom_marker_show_side_bands: bool
    :param custom_marker_show_peaks: Required.
    :type custom_marker_show_peaks: bool
    """

    _validation = {
        'custom_marker_id': {'required': True},
        'custom_marker_name': {'max_length': 5},
        'custom_marker_show_harmonics': {'required': True},
        'custom_marker_show_side_bands': {'required': True},
        'custom_marker_show_peaks': {'required': True},
    }

    _attribute_map = {
        'custom_marker_id': {'key': 'CustomMarkerId', 'type': 'str'},
        'custom_marker_name': {'key': 'CustomMarkerName', 'type': 'str'},
        'custom_marker_show_harmonics': {'key': 'CustomMarkerShowHarmonics', 'type': 'bool'},
        'custom_marker_show_side_bands': {'key': 'CustomMarkerShowSideBands', 'type': 'bool'},
        'custom_marker_show_peaks': {'key': 'CustomMarkerShowPeaks', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(CustomMarkerChild, self).__init__(**kwargs)
        self.custom_marker_id = kwargs.get('custom_marker_id', None)
        self.custom_marker_name = kwargs.get('custom_marker_name', None)
        self.custom_marker_show_harmonics = kwargs.get('custom_marker_show_harmonics', None)
        self.custom_marker_show_side_bands = kwargs.get('custom_marker_show_side_bands', None)
        self.custom_marker_show_peaks = kwargs.get('custom_marker_show_peaks', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ExternalNotificationChild(Model):
    """ExternalNotificationChild.

    :param external_notification_id:
    :type external_notification_id: str
    :param external_notification_requested_time:
    :type external_notification_requested_time: datetime
    :param external_notification_user:
    :type external_notification_user: ~smartdiagnostics_sdk.models.UserChild
    """

    _attribute_map = {
        'external_notification_id': {'key': 'ExternalNotificationId', 'type': 'str'},
        'external_notification_requested_time': {'key': 'ExternalNotificationRequestedTime', 'type': 'iso-8601'},
        'external_notification_user': {'key': 'ExternalNotificationUser', 'type': 'UserChild'},
    }

    def __init__(self, **kwargs):
        super(ExternalNotificationChild, self).__init__(**kwargs)
        self.external_notification_id = kwargs.get('external_notification_id', None)
        self.external_notification_requested_time = kwargs.get('external_notification_requested_time', None)
        self.external_notification_user = kwargs.get('external_notification_user', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class LongBurstRequestChild(Model):
    """LongBurstRequestChild.

    :param long_burst_request_id:
    :type long_burst_request_id: long
    :param long_burst_request_status: Possible values include: 'Unknown',
     'Failed', 'Canceled', 'TimedOut', 'Initiated', 'Enqueued', 'Capturing',
     'Processing', 'Completed'
    :type long_burst_request_status: str or ~smartdiagnostics_sdk.models.enum
    :param requested_time:
    :type requested_time: datetime
    :param completed_time:
    :type completed_time: datetime
    :param requested_by_user:
    :type requested_by_user: ~smartdiagnostics_sdk.models.UserChild
    :param xaxis_long_burst_file:
    :type xaxis_long_burst_file: str
    :param yaxis_long_burst_file:
    :type yaxis_long_burst_file: str
    """

    _attribute_map = {
        'long_burst_request_id': {'key': 'LongBurstRequestId', 'type': 'long'},
        'long_burst_request_status': {'key': 'LongBurstRequestStatus', 'type': 'str'},
        'requested_time': {'key': 'RequestedTime', 'type': 'iso-8601'},
        'completed_time': {'key': 'CompletedTime', 'type': 'iso-8601'},
        'requested_by_user': {'key': 'RequestedByUser', 'type': 'UserChild'},
        'xaxis_long_burst_file': {'key': 'XAxisLongBurstFile', 'type': 'str'},
        'yaxis_long_burst_file': {'key': 'YAxisLongBurstFile', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(LongBurstRequestChild, self).__init__(**kwargs)
        self.long_burst_request_id = kwargs.get('long_burst_request_id', None)
        self.long_burst_request_status = kwargs.get('long_burst_request_status', None)
        self.requested_time = kwargs.get('requested_time', None)
        self.completed_time = kwargs.get('completed_time', None)
        self.requested_by_user = kwargs.get('requested_by_user', None)
        self.xaxis_long_burst_file = kwargs.get('xaxis_long_burst_file', None)
        self.yaxis_long_burst_file = kwargs.get('yaxis_long_burst_file', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class InstallNodesStatusChild(Model):
    """InstallNodesStatusChild.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :ivar total:
    :vartype total: int
    :param status:
    :type status: ~smartdiagnostics_sdk.models.NodeStatusChild
    """

    _validation = {
        'total': {'readonly': True},
    }

    _attribute_map = {
        'total': {'key': 'Total', 'type': 'int'},
        'status': {'key': 'Status', 'type': 'NodeStatusChild'},
    }

    def __init__(self, **kwargs):
        super(InstallNodesStatusChild, self).__init__(**kwargs)
        self.total = None
        self.status = kwargs.get('status', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AssetCategoryWithSizeChild(Model):
    """AssetCategoryWithSizeChild.

    All required parameters must be populated in order to send to Azure.

    :param category_id: Required.
    :type category_id: int
    :param category_name: Required.
    :type category_name: str
    :param category_code: Required.
    :type category_code: str
    :param category_marker:
    :type category_marker:
     ~smartdiagnostics_sdk.models.AssetCategoryMarkerChild
    :param category_sizes:
    :type category_sizes: list[~smartdiagnostics_sdk.models.AssetSizeChild]
    """

    _validation = {
        'category_id': {'required': True},
        'category_name': {'required': True},
        'category_code': {'required': True},
    }

    _attribute_map = {
        'category_id': {'key': 'CategoryId', 'type': 'int'},
        'category_name': {'key': 'CategoryName', 'type': 'str'},
        'category_code': {'key': 'CategoryCode', 'type': 'str'},
        'category_marker': {'key': 'CategoryMarker', 'type': 'AssetCategoryMarkerChild'},
        'category_sizes': {'key': 'CategorySizes', 'type': '[AssetSizeChild]'},
    }

    def __init__(self, *, category_id: int, category_name: str, category_code: str, category_marker=None, category_sizes=None, **kwargs) -> None:
        super(AssetCategoryWithSizeChild, self).__init__(**kwargs)
        self.category_id = category_id
        self.category_name = category_name
        self.category_code = category_code
        self.category_marker = category_marker
        self.category_sizes = category_sizes



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MonitoringPointAssignmentResponse(Model):
    """MonitoringPointAssignmentResponse.

    :param id:
    :type id: long
    :param start_date:
    :type start_date: datetime
    :param end_date:
    :type end_date: datetime
    :param is_paused:
    :type is_paused: bool
    :param monitoring_point:
    :type monitoring_point: ~smartdiagnostics_sdk.models.MonitoringPointChild
    :param node:
    :type node: ~smartdiagnostics_sdk.models.MonitoringPointNodeChild
    :param corporation:
    :type corporation: ~smartdiagnostics_sdk.models.CorporationChild
    :param location:
    :type location: ~smartdiagnostics_sdk.models.LocationChild
    """

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'long'},
        'start_date': {'key': 'StartDate', 'type': 'iso-8601'},
        'end_date': {'key': 'EndDate', 'type': 'iso-8601'},
        'is_paused': {'key': 'IsPaused', 'type': 'bool'},
        'monitoring_point': {'key': 'MonitoringPoint', 'type': 'MonitoringPointChild'},
        'node': {'key': 'Node', 'type': 'MonitoringPointNodeChild'},
        'corporation': {'key': 'Corporation', 'type': 'CorporationChild'},
        'location': {'key': 'Location', 'type': 'LocationChild'},
    }

    def __init__(self, *, id: int=None, start_date=None, end_date=None, is_paused: bool=None, monitoring_point=None, node=None, corporation=None, location=None, **kwargs) -> None:
        super(MonitoringPointAssignmentResponse, self).__init__(**kwargs)
        self.id = id
        self.start_date = start_date
        self.end_date = end_date
        self.is_paused = is_paused
        self.monitoring_point = monitoring_point
        self.node = node
        self.corporation = corporation
        self.location = location



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MonitoringPointOverviewResponse(Model):
    """MonitoringPointOverviewResponse.

    All required parameters must be populated in order to send to Azure.

    :param id: Required.
    :type id: str
    :param name: Required.
    :type name: str
    :param monitoring_point_type: Possible values include: 'Custom',
     'Vibration', 'Pressure', 'OilQuality', 'GeneralInput', 'IndicatorBased',
     'GeneralAtoD'
    :type monitoring_point_type: str or ~smartdiagnostics_sdk.models.enum
    :param is_paused: Required.
    :type is_paused: bool
    :param is_snoozed: Required.
    :type is_snoozed: bool
    :param running_speed_multiplier:
    :type running_speed_multiplier: float
    :param node:
    :type node: ~smartdiagnostics_sdk.models.MonitoringPointOverviewNodeChild
    :param hierarchy:
    :type hierarchy: list[~smartdiagnostics_sdk.models.OverviewHierarchyChild]
    :param node_settings:
    :type node_settings: ~smartdiagnostics_sdk.models.NodeSettingOverview
    """

    _validation = {
        'id': {'required': True},
        'name': {'required': True},
        'is_paused': {'required': True},
        'is_snoozed': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'str'},
        'name': {'key': 'Name', 'type': 'str'},
        'monitoring_point_type': {'key': 'MonitoringPointType', 'type': 'str'},
        'is_paused': {'key': 'IsPaused', 'type': 'bool'},
        'is_snoozed': {'key': 'IsSnoozed', 'type': 'bool'},
        'running_speed_multiplier': {'key': 'RunningSpeedMultiplier', 'type': 'float'},
        'node': {'key': 'Node', 'type': 'MonitoringPointOverviewNodeChild'},
        'hierarchy': {'key': 'Hierarchy', 'type': '[OverviewHierarchyChild]'},
        'node_settings': {'key': 'NodeSettings', 'type': 'NodeSettingOverview'},
    }

    def __init__(self, **kwargs):
        super(MonitoringPointOverviewResponse, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.name = kwargs.get('name', None)
        self.monitoring_point_type = kwargs.get('monitoring_point_type', None)
        self.is_paused = kwargs.get('is_paused', None)
        self.is_snoozed = kwargs.get('is_snoozed', None)
        self.running_speed_multiplier = kwargs.get('running_speed_multiplier', None)
        self.node = kwargs.get('node', None)
        self.hierarchy = kwargs.get('hierarchy', None)
        self.node_settings = kwargs.get('node_settings', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DescendantChild(Model):
    """DescendantChild.

    :param child_id:
    :type child_id: str
    :param child_name:
    :type child_name: str
    :param child_abbreviation:
    :type child_abbreviation: str
    :param child_type: Possible values include: 'Asset', 'MonitoringPoint',
     'IndicatorGroup', 'Group', 'AnalyticModel'
    :type child_type: str or ~smartdiagnostics_sdk.models.enum
    :param child_sort_order:
    :type child_sort_order: int
    :param child_has_children:
    :type child_has_children: bool
    :param child_alarm_severity_level:
    :type child_alarm_severity_level: int
    :param child_is_paused:
    :type child_is_paused: bool
    :param child_is_snoozed:
    :type child_is_snoozed: bool
    """

    _attribute_map = {
        'child_id': {'key': 'ChildId', 'type': 'str'},
        'child_name': {'key': 'ChildName', 'type': 'str'},
        'child_abbreviation': {'key': 'ChildAbbreviation', 'type': 'str'},
        'child_type': {'key': 'ChildType', 'type': 'str'},
        'child_sort_order': {'key': 'ChildSortOrder', 'type': 'int'},
        'child_has_children': {'key': 'ChildHasChildren', 'type': 'bool'},
        'child_alarm_severity_level': {'key': 'ChildAlarmSeverityLevel', 'type': 'int'},
        'child_is_paused': {'key': 'ChildIsPaused', 'type': 'bool'},
        'child_is_snoozed': {'key': 'ChildIsSnoozed', 'type': 'bool'},
    }

    def __init__(self, *, child_id: str=None, child_name: str=None, child_abbreviation: str=None, child_type=None, child_sort_order: int=None, child_has_children: bool=None, child_alarm_severity_level: int=None, child_is_paused: bool=None, child_is_snoozed: bool=None, **kwargs) -> None:
        super(DescendantChild, self).__init__(**kwargs)
        self.child_id = child_id
        self.child_name = child_name
        self.child_abbreviation = child_abbreviation
        self.child_type = child_type
        self.child_sort_order = child_sort_order
        self.child_has_children = child_has_children
        self.child_alarm_severity_level = child_alarm_severity_level
        self.child_is_paused = child_is_paused
        self.child_is_snoozed = child_is_snoozed



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MoveFilesRequest(Model):
    """MoveFilesRequest.

    All required parameters must be populated in order to send to Azure.

    :param file_ids: Required. File Ids to move
    :type file_ids: list[str]
    :param destination_folder_id: Required. File to move all files to (Parent
     Id)
    :type destination_folder_id: str
    """

    _validation = {
        'file_ids': {'required': True},
        'destination_folder_id': {'required': True},
    }

    _attribute_map = {
        'file_ids': {'key': 'FileIds', 'type': '[str]'},
        'destination_folder_id': {'key': 'DestinationFolderId', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(MoveFilesRequest, self).__init__(**kwargs)
        self.file_ids = kwargs.get('file_ids', None)
        self.destination_folder_id = kwargs.get('destination_folder_id', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AlarmDefinitionChild(Model):
    """AlarmDefinitionChild.

    :param low_alarm_value:
    :type low_alarm_value: float
    :param low_warning_value:
    :type low_warning_value: float
    :param high_alarm_value:
    :type high_alarm_value: float
    :param high_warning_value:
    :type high_warning_value: float
    :param off_threshold_value:
    :type off_threshold_value: float
    :param classification:
    :type classification: str
    :param notification_criteria_percentage:
    :type notification_criteria_percentage: float
    :param notification_criteria_points:
    :type notification_criteria_points: int
    """

    _attribute_map = {
        'low_alarm_value': {'key': 'LowAlarmValue', 'type': 'float'},
        'low_warning_value': {'key': 'LowWarningValue', 'type': 'float'},
        'high_alarm_value': {'key': 'HighAlarmValue', 'type': 'float'},
        'high_warning_value': {'key': 'HighWarningValue', 'type': 'float'},
        'off_threshold_value': {'key': 'OffThresholdValue', 'type': 'float'},
        'classification': {'key': 'Classification', 'type': 'str'},
        'notification_criteria_percentage': {'key': 'NotificationCriteriaPercentage', 'type': 'float'},
        'notification_criteria_points': {'key': 'NotificationCriteriaPoints', 'type': 'int'},
    }

    def __init__(self, *, low_alarm_value: float=None, low_warning_value: float=None, high_alarm_value: float=None, high_warning_value: float=None, off_threshold_value: float=None, classification: str=None, notification_criteria_percentage: float=None, notification_criteria_points: int=None, **kwargs) -> None:
        super(AlarmDefinitionChild, self).__init__(**kwargs)
        self.low_alarm_value = low_alarm_value
        self.low_warning_value = low_warning_value
        self.high_alarm_value = high_alarm_value
        self.high_warning_value = high_warning_value
        self.off_threshold_value = off_threshold_value
        self.classification = classification
        self.notification_criteria_percentage = notification_criteria_percentage
        self.notification_criteria_points = notification_criteria_points



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PicturesModelV3(Model):
    """PicturesModelV3.

    All required parameters must be populated in order to send to Azure.

    :param id: Required.
    :type id: str
    :param description:
    :type description: str
    :param name:
    :type name: str
    :param image_file_name:
    :type image_file_name: str
    :param thumbnail_file_name:
    :type thumbnail_file_name: str
    :param attachment:
    :type attachment: ~smartdiagnostics_sdk.models.AttachmentModelV3
    """

    _validation = {
        'id': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'str'},
        'description': {'key': 'Description', 'type': 'str'},
        'name': {'key': 'Name', 'type': 'str'},
        'image_file_name': {'key': 'ImageFileName', 'type': 'str'},
        'thumbnail_file_name': {'key': 'ThumbnailFileName', 'type': 'str'},
        'attachment': {'key': 'Attachment', 'type': 'AttachmentModelV3'},
    }

    def __init__(self, *, id: str, description: str=None, name: str=None, image_file_name: str=None, thumbnail_file_name: str=None, attachment=None, **kwargs) -> None:
        super(PicturesModelV3, self).__init__(**kwargs)
        self.id = id
        self.description = description
        self.name = name
        self.image_file_name = image_file_name
        self.thumbnail_file_name = thumbnail_file_name
        self.attachment = attachment



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class HubChild(Model):
    """HubChild.

    :param hub_serial_number:
    :type hub_serial_number: str
    :param hub_name:
    :type hub_name: str
    :param hub_port_number:
    :type hub_port_number: int
    """

    _attribute_map = {
        'hub_serial_number': {'key': 'HubSerialNumber', 'type': 'str'},
        'hub_name': {'key': 'HubName', 'type': 'str'},
        'hub_port_number': {'key': 'HubPortNumber', 'type': 'int'},
    }

    def __init__(self, *, hub_serial_number: str=None, hub_name: str=None, hub_port_number: int=None, **kwargs) -> None:
        super(HubChild, self).__init__(**kwargs)
        self.hub_serial_number = hub_serial_number
        self.hub_name = hub_name
        self.hub_port_number = hub_port_number



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class IndicatorResponse(Model):
    """IndicatorResponse.

    All required parameters must be populated in order to send to Azure.

    :param id: Required.
    :type id: str
    :param name: Required.
    :type name: str
    :param system_sort_order:
    :type system_sort_order: int
    :param indicator_type: Possible values include: 'Temperature', 'Pressure',
     'Flow', 'Humidity', 'Power', 'DifferentialPressure',
     'MultiSensorDifferentialPressure', 'Voltage', 'GeneralizedAtoD',
     'VibrationBandRms', 'VibrationBandMax', 'VibrationOverallPeak',
     'VibrationOverallRms', 'VibrationOverallSkewness',
     'VibrationOverallKurtosis', 'VibrationOverallCrestFactor',
     'DamageAccumulation', 'VibrationBandRmsAccel', 'VibrationBandMaxAccel',
     'VibrationOverallPeakAccel', 'VibrationOverallRmsAccel',
     'VibrationOverallSkewnessAccel', 'VibrationOverallKurtosisAccel',
     'VibrationOverallCrestFactorAccel', 'DamageAccumulationAccel', 'Group',
     'VibrationOverall', 'VibrationOverallAccel', 'GeneralTimeSeries', 'Math',
     'OnStatistics', 'OffStatistics', 'AlarmStatistics', 'WarningStatistics',
     'PositivePeakPressure', 'NegativePeakPressure', 'RmsPressure',
     'BandPressure', 'OnPercentStatistics', 'OffPercentStatistics',
     'AlarmPercentStatistics', 'WarningPercentStatistics', 'SignalStrength',
     'RunningSpeed', 'DamageAccumulationPressure', 'OilHumidity',
     'OilTemperature', 'DamageAccumulationAccelRaw', 'ThermalRegionOfInterest',
     'SmartMetric', 'Feature'
    :type indicator_type: str or ~smartdiagnostics_sdk.models.enum
    :param sensor_role_type: Possible values include: 'Invalid',
     'CurrentPhaseA', 'PeakCurrentPhaseA', 'CurrentPhaseB',
     'PeakCurrentPhaseB', 'CurrentPhaseC', 'PeakCurrentPhaseC',
     'DifferentialPressure', 'Flow', 'Humidity', 'NodeTemperature',
     'NodeVoltage', 'PeakVibration', 'Pressure', 'RmsVibration',
     'SignalStrength', 'StandardAirVelocity', 'SupplyVoltage', 'Temperature',
     'TotalCurrent', 'VibrationXAxis', 'VibrationYAxis', 'Voltage', 'Current',
     'AtoDChannel1', 'AtoDChannel2', 'AtoDChannel3', 'AtoDChannel4',
     'AtoDChannel5', 'AtoDChannel6', 'OilTemperature', 'OilHumidity', 'X', 'Y',
     'Z', 'Custom', 'WirelessEfficiency', 'PacketSuccessRate', 'NodeHumidity',
     'BurstSuccessRate'
    :type sensor_role_type: str or ~smartdiagnostics_sdk.models.enum
    :param display_units:
    :type display_units: str
    :param base_units:
    :type base_units: str
    :param has_spectrum:
    :type has_spectrum: bool
    :param meta_data:
    :type meta_data: str
    :param damage_exponent:
    :type damage_exponent: int
    :param hierarchy:
    :type hierarchy: list[~smartdiagnostics_sdk.models.HierarchyChild]
    :param alarm_definition:
    :type alarm_definition: ~smartdiagnostics_sdk.models.AlarmDefinitionChild
    :param band_definition:
    :type band_definition: ~smartdiagnostics_sdk.models.BandDefinitionChild
    :param baseline:
    :type baseline: ~smartdiagnostics_sdk.models.BaselineIndicatorChild
    """

    _validation = {
        'id': {'required': True},
        'name': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'str'},
        'name': {'key': 'Name', 'type': 'str'},
        'system_sort_order': {'key': 'SystemSortOrder', 'type': 'int'},
        'indicator_type': {'key': 'IndicatorType', 'type': 'str'},
        'sensor_role_type': {'key': 'SensorRoleType', 'type': 'str'},
        'display_units': {'key': 'DisplayUnits', 'type': 'str'},
        'base_units': {'key': 'BaseUnits', 'type': 'str'},
        'has_spectrum': {'key': 'HasSpectrum', 'type': 'bool'},
        'meta_data': {'key': 'MetaData', 'type': 'str'},
        'damage_exponent': {'key': 'DamageExponent', 'type': 'int'},
        'hierarchy': {'key': 'Hierarchy', 'type': '[HierarchyChild]'},
        'alarm_definition': {'key': 'AlarmDefinition', 'type': 'AlarmDefinitionChild'},
        'band_definition': {'key': 'BandDefinition', 'type': 'BandDefinitionChild'},
        'baseline': {'key': 'Baseline', 'type': 'BaselineIndicatorChild'},
    }

    def __init__(self, *, id: str, name: str, system_sort_order: int=None, indicator_type=None, sensor_role_type=None, display_units: str=None, base_units: str=None, has_spectrum: bool=None, meta_data: str=None, damage_exponent: int=None, hierarchy=None, alarm_definition=None, band_definition=None, baseline=None, **kwargs) -> None:
        super(IndicatorResponse, self).__init__(**kwargs)
        self.id = id
        self.name = name
        self.system_sort_order = system_sort_order
        self.indicator_type = indicator_type
        self.sensor_role_type = sensor_role_type
        self.display_units = display_units
        self.base_units = base_units
        self.has_spectrum = has_spectrum
        self.meta_data = meta_data
        self.damage_exponent = damage_exponent
        self.hierarchy = hierarchy
        self.alarm_definition = alarm_definition
        self.band_definition = band_definition
        self.baseline = baseline



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ParentChild(Model):
    """ParentChild.

    :param parent_id:
    :type parent_id: str
    :param parent_name:
    :type parent_name: str
    :param parent_abbreviation:
    :type parent_abbreviation: str
    :param parent_type:
    :type parent_type: str
    """

    _attribute_map = {
        'parent_id': {'key': 'ParentId', 'type': 'str'},
        'parent_name': {'key': 'ParentName', 'type': 'str'},
        'parent_abbreviation': {'key': 'ParentAbbreviation', 'type': 'str'},
        'parent_type': {'key': 'ParentType', 'type': 'str'},
    }

    def __init__(self, *, parent_id: str=None, parent_name: str=None, parent_abbreviation: str=None, parent_type: str=None, **kwargs) -> None:
        super(ParentChild, self).__init__(**kwargs)
        self.parent_id = parent_id
        self.parent_name = parent_name
        self.parent_abbreviation = parent_abbreviation
        self.parent_type = parent_type



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GroupAlertsResponse(Model):
    """GroupAlertsResponse.

    :param indicator_id:
    :type indicator_id: str
    :param indicator_name:
    :type indicator_name: str
    :param indicator_sort_order:
    :type indicator_sort_order: int
    :param hierarchy:
    :type hierarchy: list[~smartdiagnostics_sdk.models.HierarchyChild]
    :param time_of_alert:
    :type time_of_alert: datetime
    :param external_notification:
    :type external_notification:
     ~smartdiagnostics_sdk.models.ExternalNotificationChild
    """

    _attribute_map = {
        'indicator_id': {'key': 'IndicatorId', 'type': 'str'},
        'indicator_name': {'key': 'IndicatorName', 'type': 'str'},
        'indicator_sort_order': {'key': 'IndicatorSortOrder', 'type': 'int'},
        'hierarchy': {'key': 'Hierarchy', 'type': '[HierarchyChild]'},
        'time_of_alert': {'key': 'TimeOfAlert', 'type': 'iso-8601'},
        'external_notification': {'key': 'ExternalNotification', 'type': 'ExternalNotificationChild'},
    }

    def __init__(self, *, indicator_id: str=None, indicator_name: str=None, indicator_sort_order: int=None, hierarchy=None, time_of_alert=None, external_notification=None, **kwargs) -> None:
        super(GroupAlertsResponse, self).__init__(**kwargs)
        self.indicator_id = indicator_id
        self.indicator_name = indicator_name
        self.indicator_sort_order = indicator_sort_order
        self.hierarchy = hierarchy
        self.time_of_alert = time_of_alert
        self.external_notification = external_notification



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UserLocationChild(Model):
    """UserLocationChild.

    All required parameters must be populated in order to send to Azure.

    :param location_id: Required.
    :type location_id: str
    :param location_name: Required.
    :type location_name: str
    :param location_abbreviation:
    :type location_abbreviation: str
    :param location_user_role: Possible values include: 'Invalid',
     'SaasAdmin', 'AccountAdmin', 'ApplicationUser', 'Technician', 'User',
     'SystemProcess', 'Sentry', 'Sales', 'CorporationAdmin', 'CorporationUser',
     'CorporationNone'
    :type location_user_role: str or ~smartdiagnostics_sdk.models.enum
    """

    _validation = {
        'location_id': {'required': True},
        'location_name': {'required': True},
    }

    _attribute_map = {
        'location_id': {'key': 'LocationId', 'type': 'str'},
        'location_name': {'key': 'LocationName', 'type': 'str'},
        'location_abbreviation': {'key': 'LocationAbbreviation', 'type': 'str'},
        'location_user_role': {'key': 'LocationUserRole', 'type': 'str'},
    }

    def __init__(self, *, location_id: str, location_name: str, location_abbreviation: str=None, location_user_role=None, **kwargs) -> None:
        super(UserLocationChild, self).__init__(**kwargs)
        self.location_id = location_id
        self.location_name = location_name
        self.location_abbreviation = location_abbreviation
        self.location_user_role = location_user_role



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class LayoutChild(Model):
    """LayoutChild.

    All required parameters must be populated in order to send to Azure.

    :param layout_row: Required.
    :type layout_row: int
    :param layout_column: Required.
    :type layout_column: int
    :param layout_height: Required.
    :type layout_height: int
    :param layout_width: Required.
    :type layout_width: int
    """

    _validation = {
        'layout_row': {'required': True},
        'layout_column': {'required': True},
        'layout_height': {'required': True},
        'layout_width': {'required': True},
    }

    _attribute_map = {
        'layout_row': {'key': 'LayoutRow', 'type': 'int'},
        'layout_column': {'key': 'LayoutColumn', 'type': 'int'},
        'layout_height': {'key': 'LayoutHeight', 'type': 'int'},
        'layout_width': {'key': 'LayoutWidth', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(LayoutChild, self).__init__(**kwargs)
        self.layout_row = kwargs.get('layout_row', None)
        self.layout_column = kwargs.get('layout_column', None)
        self.layout_height = kwargs.get('layout_height', None)
        self.layout_width = kwargs.get('layout_width', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BandDefinitionChild(Model):
    """BandDefinitionChild.

    :param high_band_frequency:
    :type high_band_frequency: float
    :param low_band_frequency:
    :type low_band_frequency: float
    """

    _attribute_map = {
        'high_band_frequency': {'key': 'HighBandFrequency', 'type': 'float'},
        'low_band_frequency': {'key': 'LowBandFrequency', 'type': 'float'},
    }

    def __init__(self, *, high_band_frequency: float=None, low_band_frequency: float=None, **kwargs) -> None:
        super(BandDefinitionChild, self).__init__(**kwargs)
        self.high_band_frequency = high_band_frequency
        self.low_band_frequency = low_band_frequency



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FilesUpdateRequest(Model):
    """FilesUpdateRequest.

    All required parameters must be populated in order to send to Azure.

    :param display_name:
    :type display_name: str
    :param parent_folder_id: Required.
    :type parent_folder_id: str
    :param description:
    :type description: str
    :param group_ids:
    :type group_ids: list[str]
    """

    _validation = {
        'display_name': {'max_length': 223},
        'parent_folder_id': {'required': True},
    }

    _attribute_map = {
        'display_name': {'key': 'DisplayName', 'type': 'str'},
        'parent_folder_id': {'key': 'ParentFolderId', 'type': 'str'},
        'description': {'key': 'Description', 'type': 'str'},
        'group_ids': {'key': 'GroupIds', 'type': '[str]'},
    }

    def __init__(self, **kwargs):
        super(FilesUpdateRequest, self).__init__(**kwargs)
        self.display_name = kwargs.get('display_name', None)
        self.parent_folder_id = kwargs.get('parent_folder_id', None)
        self.description = kwargs.get('description', None)
        self.group_ids = kwargs.get('group_ids', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class HardwareModelV3(Model):
    """This class is meant to be used for all hardware Models.

    All required parameters must be populated in order to send to Azure.

    :param id: Required. Hardware's Id
    :type id: long
    :param serial_number: Required. Serial Number of hardware
    :type serial_number: str
    :param nickname: Nickname of the hardware
    :type nickname: str
    """

    _validation = {
        'id': {'required': True},
        'serial_number': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'long'},
        'serial_number': {'key': 'SerialNumber', 'type': 'str'},
        'nickname': {'key': 'Nickname', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(HardwareModelV3, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.serial_number = kwargs.get('serial_number', None)
        self.nickname = kwargs.get('nickname', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BearingChild(Model):
    """BearingChild.

    :param bearing_id:
    :type bearing_id: str
    :param bearing_name:
    :type bearing_name: str
    :param bearing_manufacturer:
    :type bearing_manufacturer: str
    :param bearing_bpfi:
    :type bearing_bpfi: float
    """

    _attribute_map = {
        'bearing_id': {'key': 'BearingId', 'type': 'str'},
        'bearing_name': {'key': 'BearingName', 'type': 'str'},
        'bearing_manufacturer': {'key': 'BearingManufacturer', 'type': 'str'},
        'bearing_bpfi': {'key': 'BearingBpfi', 'type': 'float'},
    }

    def __init__(self, **kwargs):
        super(BearingChild, self).__init__(**kwargs)
        self.bearing_id = kwargs.get('bearing_id', None)
        self.bearing_name = kwargs.get('bearing_name', None)
        self.bearing_manufacturer = kwargs.get('bearing_manufacturer', None)
        self.bearing_bpfi = kwargs.get('bearing_bpfi', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WidgetTypeChild(Model):
    """WidgetTypeChild.

    All required parameters must be populated in order to send to Azure.

    :param widget_type_id: Required.
    :type widget_type_id: int
    :param widget_type_name: Required. Possible values include: 'Value',
     'Table', 'Kpi', 'Series'
    :type widget_type_name: str or ~smartdiagnostics_sdk.models.enum
    :param widget_type_description:
    :type widget_type_description: str
    """

    _validation = {
        'widget_type_id': {'required': True},
        'widget_type_name': {'required': True},
    }

    _attribute_map = {
        'widget_type_id': {'key': 'WidgetTypeId', 'type': 'int'},
        'widget_type_name': {'key': 'WidgetTypeName', 'type': 'str'},
        'widget_type_description': {'key': 'WidgetTypeDescription', 'type': 'str'},
    }

    def __init__(self, *, widget_type_id: int, widget_type_name, widget_type_description: str=None, **kwargs) -> None:
        super(WidgetTypeChild, self).__init__(**kwargs)
        self.widget_type_id = widget_type_id
        self.widget_type_name = widget_type_name
        self.widget_type_description = widget_type_description



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AnalyticsModelIndicatorChild(Model):
    """AnalyticsModelIndicatorChild.

    All required parameters must be populated in order to send to Azure.

    :param indicator_name: Required.
    :type indicator_name: str
    :param indicator_units:
    :type indicator_units: str
    :param indicator_type: Required. Possible values include: 'Temperature',
     'Pressure', 'Flow', 'Humidity', 'Power', 'DifferentialPressure',
     'MultiSensorDifferentialPressure', 'Voltage', 'GeneralizedAtoD',
     'VibrationBandRms', 'VibrationBandMax', 'VibrationOverallPeak',
     'VibrationOverallRms', 'VibrationOverallSkewness',
     'VibrationOverallKurtosis', 'VibrationOverallCrestFactor',
     'DamageAccumulation', 'VibrationBandRmsAccel', 'VibrationBandMaxAccel',
     'VibrationOverallPeakAccel', 'VibrationOverallRmsAccel',
     'VibrationOverallSkewnessAccel', 'VibrationOverallKurtosisAccel',
     'VibrationOverallCrestFactorAccel', 'DamageAccumulationAccel', 'Group',
     'VibrationOverall', 'VibrationOverallAccel', 'GeneralTimeSeries', 'Math',
     'OnStatistics', 'OffStatistics', 'AlarmStatistics', 'WarningStatistics',
     'PositivePeakPressure', 'NegativePeakPressure', 'RmsPressure',
     'BandPressure', 'OnPercentStatistics', 'OffPercentStatistics',
     'AlarmPercentStatistics', 'WarningPercentStatistics', 'SignalStrength',
     'RunningSpeed', 'DamageAccumulationPressure', 'OilHumidity',
     'OilTemperature', 'DamageAccumulationAccelRaw', 'ThermalRegionOfInterest',
     'SmartMetric', 'Feature'
    :type indicator_type: str or ~smartdiagnostics_sdk.models.enum
    """

    _validation = {
        'indicator_name': {'required': True},
        'indicator_type': {'required': True},
    }

    _attribute_map = {
        'indicator_name': {'key': 'IndicatorName', 'type': 'str'},
        'indicator_units': {'key': 'IndicatorUnits', 'type': 'str'},
        'indicator_type': {'key': 'IndicatorType', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(AnalyticsModelIndicatorChild, self).__init__(**kwargs)
        self.indicator_name = kwargs.get('indicator_name', None)
        self.indicator_units = kwargs.get('indicator_units', None)
        self.indicator_type = kwargs.get('indicator_type', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TimeRangeModelV3(Model):
    """TimeRangeModelV3.

    :param start_date:
    :type start_date: datetime
    :param end_date:
    :type end_date: datetime
    """

    _attribute_map = {
        'start_date': {'key': 'StartDate', 'type': 'iso-8601'},
        'end_date': {'key': 'EndDate', 'type': 'iso-8601'},
    }

    def __init__(self, *, start_date=None, end_date=None, **kwargs) -> None:
        super(TimeRangeModelV3, self).__init__(**kwargs)
        self.start_date = start_date
        self.end_date = end_date



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UserChild(Model):
    """UserChild.

    :param user_id:
    :type user_id: str
    :param user_first_name:
    :type user_first_name: str
    :param user_last_name:
    :type user_last_name: str
    :param user_email:
    :type user_email: str
    """

    _attribute_map = {
        'user_id': {'key': 'UserId', 'type': 'str'},
        'user_first_name': {'key': 'UserFirstName', 'type': 'str'},
        'user_last_name': {'key': 'UserLastName', 'type': 'str'},
        'user_email': {'key': 'UserEmail', 'type': 'str'},
    }

    def __init__(self, *, user_id: str=None, user_first_name: str=None, user_last_name: str=None, user_email: str=None, **kwargs) -> None:
        super(UserChild, self).__init__(**kwargs)
        self.user_id = user_id
        self.user_first_name = user_first_name
        self.user_last_name = user_last_name
        self.user_email = user_email
